@@ -44,11 +44,13 @@
 
 #include <ola/ExportMap.h>
 #include <ola/Logging.h>
+#include <ola/base/Flags.h>
 #include <ola/base/Init.h>
 #include <ola/base/SysExits.h>
 #include <ola/math/Random.h>
 
 #include <iostream>
+#include <string>
 
 namespace ola {
 
@@ -66,7 +68,7 @@ using std::endl;
  * Print a stack trace on seg fault.
  */
 static void _SIGSEGV_Handler(int signal) {
-  cout << "Recieved SIGSEGV or SIGBUS" << endl;
+  cout << "Received SIGSEGV or SIGBUS" << endl;
   #ifdef HAVE_EXECINFO_H
   enum {STACK_SIZE = 64};
   void *array[STACK_SIZE];
@@ -90,13 +92,29 @@ bool ServerInit(int argc, char *argv[], ExportMap *export_map) {
 }
 
 
-bool AppInit(int argc, char *argv[]) {
+bool ServerInit(int *argc,
+                char *argv[],
+                ExportMap *export_map,
+                const std::string &first_line,
+                const std::string &description) {
+  SetHelpString(first_line, description);
+  ParseFlags(argc, argv);
+  InitLoggingFromFlags();
+  return ServerInit(*argc, argv, export_map);
+}
+
+
+bool AppInit(int *argc,
+             char *argv[],
+             const std::string &first_line,
+             const std::string &description) {
   ola::math::InitRandom();
+  SetHelpString(first_line, description);
+  ParseFlags(argc, argv);
+  InitLoggingFromFlags();
   if (!InstallSEGVHandler())
     return false;
   return true;
-  (void) argc;
-  (void) argv;
 }
 
 
