@@ -26,8 +26,8 @@
 namespace ola {
 namespace rdm {
 
-UID* UID::FromString(const string &uid) {
-  std::vector<string> tokens;
+UID* UID::FromString(const std::string &uid) {
+  std::vector<std::string> tokens;
   ola::StringSplit(uid, tokens, ":");
 
   if (tokens.size() != 2 || tokens[0].size() != 4 || tokens[1].size() != 8)
