@@ -15,7 +15,7 @@
  *
  * StringUtilsTest.cpp
  * Unittest for String functions.
- * Copyright (C) 2005-2008 Simon Newton
+ * Copyright (C) 2005-2014 Simon Newton
  */
 
 #include <cppunit/extensions/HelperMacros.h>
@@ -31,10 +31,12 @@ using ola::CapitalizeLabel;
 using ola::CustomCapitalizeLabel;
 using ola::Escape;
 using ola::EscapeString;
+using ola::EncodeString;
 using ola::FormatData;
 using ola::HexStringToInt;
 using ola::IntToString;
 using ola::PrefixedHexStringToInt;
+using ola::ReplaceAll;
 using ola::ShortenString;
 using ola::StringEndsWith;
 using ola::StringJoin;
@@ -55,6 +57,7 @@ class StringUtilsTest: public CppUnit::TestFixture {
   CPPUNIT_TEST(testEndsWith);
   CPPUNIT_TEST(testIntToString);
   CPPUNIT_TEST(testEscape);
+  CPPUNIT_TEST(testEncodeString);
   CPPUNIT_TEST(testStringToBool);
   CPPUNIT_TEST(testStringToUInt);
   CPPUNIT_TEST(testStringToUInt16);
@@ -70,15 +73,17 @@ class StringUtilsTest: public CppUnit::TestFixture {
   CPPUNIT_TEST(testCustomCapitalizeLabel);
   CPPUNIT_TEST(testFormatData);
   CPPUNIT_TEST(testStringJoin);
+  CPPUNIT_TEST(testReplaceAll);
   CPPUNIT_TEST_SUITE_END();
 
-  public:
+ public:
     void testSplit();
     void testTrim();
     void testShorten();
     void testEndsWith();
     void testIntToString();
     void testEscape();
+    void testEncodeString();
     void testStringToBool();
     void testStringToUInt();
     void testStringToUInt16();
@@ -94,6 +99,7 @@ class StringUtilsTest: public CppUnit::TestFixture {
     void testCustomCapitalizeLabel();
     void testFormatData();
     void testStringJoin();
+    void testReplaceAll();
 };
 
 
@@ -261,12 +267,35 @@ void StringUtilsTest::testEscape() {
       result);
 }
 
+
+/**
+ * Test encoding string
+ */
+void StringUtilsTest::testEncodeString() {
+  string s1 = "foo";
+  OLA_ASSERT_EQ(string("foo"), EncodeString(s1));
+
+  s1 = "newline\ntest";
+  OLA_ASSERT_EQ(string("newline\\x0atest"), EncodeString(s1));
+
+  s1 = "newline\n\ntest";
+  OLA_ASSERT_EQ(string("newline\\x0a\\x0atest"), EncodeString(s1));
+
+  s1 = "\x01newline\x02test";
+  OLA_ASSERT_EQ(string("\\x01newline\\x02test"), EncodeString(s1));
+
+  // Test a null in the middle of a string
+  s1 = string("newline" "\x00" "test", 12);
+  OLA_ASSERT_EQ(string("newline\\x00test"), EncodeString(s1));
+}
+
+
 void StringUtilsTest::testStringToBool() {
   bool value;
   OLA_ASSERT_FALSE(StringToBool("", &value));
   OLA_ASSERT_FALSE(StringToBool("-1", &value));
-  OLA_ASSERT_FALSE(StringToBool("1", &value));
-  OLA_ASSERT_FALSE(StringToBool("0", &value));
+  OLA_ASSERT_FALSE(StringToBool("2", &value));
+  OLA_ASSERT_FALSE(StringToBool("a", &value));
   OLA_ASSERT_TRUE(StringToBool("true", &value));
   OLA_ASSERT_EQ(value, true);
   OLA_ASSERT_TRUE(StringToBool("false", &value));
@@ -275,8 +304,21 @@ void StringUtilsTest::testStringToBool() {
   OLA_ASSERT_EQ(value, true);
   OLA_ASSERT_TRUE(StringToBool("FalSe", &value));
   OLA_ASSERT_EQ(value, false);
+  OLA_ASSERT_TRUE(StringToBool("t", &value));
+  OLA_ASSERT_EQ(value, true);
+  OLA_ASSERT_TRUE(StringToBool("f", &value));
+  OLA_ASSERT_EQ(value, false);
+  OLA_ASSERT_TRUE(StringToBool("T", &value));
+  OLA_ASSERT_EQ(value, true);
+  OLA_ASSERT_TRUE(StringToBool("F", &value));
+  OLA_ASSERT_EQ(value, false);
+  OLA_ASSERT_TRUE(StringToBool("1", &value));
+  OLA_ASSERT_EQ(value, true);
+  OLA_ASSERT_TRUE(StringToBool("0", &value));
+  OLA_ASSERT_EQ(value, false);
 }
 
+
 void StringUtilsTest::testStringToUInt() {
   unsigned int value;
   OLA_ASSERT_FALSE(StringToInt("", &value));
@@ -478,6 +520,13 @@ void StringUtilsTest::testPrefixedHexStringToInt() {
   OLA_ASSERT_EQ(28927, value);
   OLA_ASSERT_TRUE(PrefixedHexStringToInt("0xffffffff", &value));
   OLA_ASSERT_EQ(-1, value);
+
+  OLA_ASSERT_TRUE(PrefixedHexStringToInt("0X7f", &value));
+  OLA_ASSERT_EQ(127, value);
+  OLA_ASSERT_TRUE(PrefixedHexStringToInt("0X7F", &value));
+  OLA_ASSERT_EQ(127, value);
+  OLA_ASSERT_TRUE(PrefixedHexStringToInt("0x7F", &value));
+  OLA_ASSERT_EQ(127, value);
 }
 
 
@@ -623,7 +672,7 @@ void StringUtilsTest::testCapitalizeLabel() {
   string label = "this-is_a_test";
   CapitalizeLabel(&label);
   OLA_ASSERT_EQ(string("This Is A Test"), label);
-};
+}
 
 
 void StringUtilsTest::testCustomCapitalizeLabel() {
@@ -650,7 +699,19 @@ void StringUtilsTest::testCustomCapitalizeLabel() {
   string label6 = "controller_ip_address";
   CustomCapitalizeLabel(&label6);
   OLA_ASSERT_EQ(string("Controller IP Address"), label6);
-};
+
+  string label7 = "dazzled_led_type";
+  CustomCapitalizeLabel(&label7);
+  OLA_ASSERT_EQ(string("Dazzled LED Type"), label7);
+
+  string label8 = "device_rdm_uid";
+  CustomCapitalizeLabel(&label8);
+  OLA_ASSERT_EQ(string("Device RDM UID"), label8);
+
+  string label9 = "dns_via_ipv4_dhcp";
+  CustomCapitalizeLabel(&label9);
+  OLA_ASSERT_EQ(string("DNS Via IPV4 DHCP"), label9);
+}
 
 
 void StringUtilsTest::testFormatData() {
@@ -683,6 +744,7 @@ void StringUtilsTest::testFormatData() {
       str.str());
 }
 
+
 void StringUtilsTest::testStringJoin() {
   vector<int> ints;
   ints.push_back(1);
@@ -696,3 +758,32 @@ void StringUtilsTest::testStringJoin() {
   strings.push_back("three");
   OLA_ASSERT_EQ(string("one,two,three"), StringJoin(",", strings));
 }
+
+
+void StringUtilsTest::testReplaceAll() {
+  string input = "";
+  ReplaceAll(&input, "", "");
+  OLA_ASSERT_EQ(string(""), input);
+
+  input = "abc";
+  ReplaceAll(&input, "", "");
+  OLA_ASSERT_EQ(string("abc"), input);
+  ReplaceAll(&input, "", "def");
+  OLA_ASSERT_EQ(string("abc"), input);
+
+  input = "abc";
+  ReplaceAll(&input, "b", "d");
+  OLA_ASSERT_EQ(string("adc"), input);
+
+  input = "aaa";
+  ReplaceAll(&input, "a", "b");
+  OLA_ASSERT_EQ(string("bbb"), input);
+
+  input = "abcdef";
+  ReplaceAll(&input, "cd", "cds");
+  OLA_ASSERT_EQ(string("abcdsef"), input);
+
+  input = "abcdefabcdef";
+  ReplaceAll(&input, "cd", "gh");
+  OLA_ASSERT_EQ(string("abghefabghef"), input);
+}
