@@ -22,7 +22,8 @@
 #define OLAD_CLIENT_H_
 
 #include <map>
-#include "common/rpc/SimpleRpcController.h"
+#include "common/rpc/RpcController.h"
+#include "ola/base/Macro.h"
 #include "olad/DmxSource.h"
 
 namespace ola {
@@ -34,29 +35,27 @@ namespace proto {
 
 namespace ola {
 
-using std::map;
-using ola::proto::OlaClientService_Stub;
-
 class Client {
-  public :
-    explicit Client(OlaClientService_Stub *client_stub):
-      m_client_stub(client_stub) {}
-    virtual ~Client();
-    virtual bool SendDMX(unsigned int universe_id, uint8_t priority,
-                         const DmxBuffer &buffer);
+ public :
+  explicit Client(ola::proto::OlaClientService_Stub *client_stub)
+    : m_client_stub(client_stub) {}
+  virtual ~Client();
+  virtual bool SendDMX(unsigned int universe_id, uint8_t priority,
+                       const DmxBuffer &buffer);
 
-    void SendDMXCallback(ola::rpc::SimpleRpcController *controller,
-                         ola::proto::Ack *ack);
-    void DMXRecieved(unsigned int universe, const DmxSource &source);
-    const DmxSource SourceData(unsigned int universe) const;
-    class OlaClientService_Stub *Stub() const { return m_client_stub; }
+  void SendDMXCallback(ola::rpc::RpcController *controller,
+                       ola::proto::Ack *ack);
+  void DMXReceived(unsigned int universe, const DmxSource &source);
+  const DmxSource SourceData(unsigned int universe) const;
+  class ola::proto::OlaClientService_Stub *Stub() const {
+    return m_client_stub;
+  }
 
-  private:
-    Client(const Client&);
-    Client& operator=(const Client&);
+ private:
+  class ola::proto::OlaClientService_Stub *m_client_stub;
+  std::map<unsigned int, DmxSource> m_data_map;
 
-    class OlaClientService_Stub *m_client_stub;
-    map<unsigned int, DmxSource> m_data_map;
+  DISALLOW_COPY_AND_ASSIGN(Client);
 };
 }  // namespace ola
 #endif  // OLAD_CLIENT_H_
