@@ -22,9 +22,5 @@
 
 namespace ola {
 
-const uint8_t DmxSource::PRIORITY_MIN = 0;
-const uint8_t DmxSource::PRIORITY_MAX = 200;
-const uint8_t DmxSource::PRIORITY_DEFAULT = 100;
-
 const TimeInterval DmxSource::TIMEOUT_INTERVAL(2500000);  // 2.5s
 }  // namespace ola
