@@ -20,7 +20,6 @@
  */
 
 #include <algorithm>
-#include <set>
 #include <string>
 #include <vector>
 #include "common/protocol/Ola.pb.h"
@@ -47,7 +46,7 @@
 
 namespace ola {
 
-using google::protobuf::RpcController;
+using ola::CallbackRunner;
 using ola::proto::Ack;
 using ola::proto::DeviceConfigReply;
 using ola::proto::DeviceConfigRequest;
@@ -69,16 +68,14 @@ using ola::proto::UniverseInfo;
 using ola::proto::UniverseInfoReply;
 using ola::proto::UniverseNameRequest;
 using ola::proto::UniverseRequest;
-using ola::CallbackRunner;
-using ola::rdm::UIDSet;
 using ola::rdm::RDMResponse;
-using std::set;
+using ola::rdm::UID;
+using ola::rdm::UIDSet;
+using ola::rpc::RpcController;
+using std::string;
+using std::vector;
 
-
-typedef CallbackRunner<google::protobuf::Closure> ClosureRunner;
-
-OlaServerServiceImpl::~OlaServerServiceImpl() {
-}
+typedef CallbackRunner<ola::rpc::RpcService::CompletionCallback> ClosureRunner;
 
 
 /*
@@ -88,7 +85,7 @@ void OlaServerServiceImpl::GetDmx(
     RpcController* controller,
     const UniverseRequest* request,
     DmxData* response,
-    google::protobuf::Closure* done) {
+    ola::rpc::RpcService::CompletionCallback* done) {
   ClosureRunner runner(done);
   Universe *universe = m_universe_store->GetUniverse(request->universe());
   if (!universe)
@@ -108,7 +105,7 @@ void OlaServerServiceImpl::RegisterForDmx(
     RpcController* controller,
     const RegisterDmxRequest* request,
     Ack*,
-    google::protobuf::Closure* done,
+    ola::rpc::RpcService::CompletionCallback* done,
     Client *client) {
   ClosureRunner runner(done);
   Universe *universe = m_universe_store->GetUniverseOrCreate(
@@ -131,7 +128,7 @@ void OlaServerServiceImpl::UpdateDmxData(
     RpcController* controller,
     const DmxData* request,
     Ack*,
-    google::protobuf::Closure* done,
+    ola::rpc::RpcService::CompletionCallback* done,
     Client *client) {
   ClosureRunner runner(done);
   Universe *universe = m_universe_store->GetUniverse(request->universe());
@@ -142,14 +139,16 @@ void OlaServerServiceImpl::UpdateDmxData(
     DmxBuffer buffer;
     buffer.Set(request->data());
 
-    uint8_t priority = DmxSource::PRIORITY_DEFAULT;
+    uint8_t priority = ola::dmx::SOURCE_PRIORITY_DEFAULT;
     if (request->has_priority()) {
       priority = request->priority();
-      priority = std::max(DmxSource::PRIORITY_MIN, priority);
-      priority = std::min(DmxSource::PRIORITY_MAX, priority);
+      priority = std::max(static_cast<uint8_t>(ola::dmx::SOURCE_PRIORITY_MIN),
+                          priority);
+      priority = std::min(static_cast<uint8_t>(ola::dmx::SOURCE_PRIORITY_MAX),
+                          priority);
     }
     DmxSource source(buffer, *m_wake_up_time, priority);
-    client->DMXRecieved(request->universe(), source);
+    client->DMXReceived(request->universe(), source);
     universe->SourceClientDataChanged(client);
   }
 }
@@ -160,9 +159,9 @@ void OlaServerServiceImpl::UpdateDmxData(
  */
 void OlaServerServiceImpl::StreamDmxData(
     RpcController*,
-    const ::ola::proto::DmxData* request,
-    ::ola::proto::STREAMING_NO_RESPONSE*,
-    ::google::protobuf::Closure*,
+    const ola::proto::DmxData* request,
+    ola::proto::STREAMING_NO_RESPONSE*,
+    ola::rpc::RpcService::CompletionCallback*,
     Client *client) {
 
   Universe *universe = m_universe_store->GetUniverse(request->universe());
@@ -174,14 +173,16 @@ void OlaServerServiceImpl::StreamDmxData(
     DmxBuffer buffer;
     buffer.Set(request->data());
 
-    uint8_t priority = DmxSource::PRIORITY_DEFAULT;
+    uint8_t priority = ola::dmx::SOURCE_PRIORITY_DEFAULT;
     if (request->has_priority()) {
       priority = request->priority();
-      priority = std::max(DmxSource::PRIORITY_MIN, priority);
-      priority = std::min(DmxSource::PRIORITY_MAX, priority);
+      priority = std::max(static_cast<uint8_t>(ola::dmx::SOURCE_PRIORITY_MIN),
+                          priority);
+      priority = std::min(static_cast<uint8_t>(ola::dmx::SOURCE_PRIORITY_MAX),
+                          priority);
     }
     DmxSource source(buffer, *m_wake_up_time, priority);
-    client->DMXRecieved(request->universe(), source);
+    client->DMXReceived(request->universe(), source);
     universe->SourceClientDataChanged(client);
   }
 }
@@ -194,7 +195,7 @@ void OlaServerServiceImpl::SetUniverseName(
     RpcController* controller,
     const UniverseNameRequest* request,
     Ack*,
-    google::protobuf::Closure* done) {
+    ola::rpc::RpcService::CompletionCallback* done) {
   ClosureRunner runner(done);
   Universe *universe = m_universe_store->GetUniverse(request->universe());
   if (!universe)
@@ -211,7 +212,7 @@ void OlaServerServiceImpl::SetMergeMode(
     RpcController* controller,
     const MergeModeRequest* request,
     Ack*,
-    google::protobuf::Closure* done) {
+    ola::rpc::RpcService::CompletionCallback* done) {
   ClosureRunner runner(done);
   Universe *universe = m_universe_store->GetUniverse(request->universe());
   if (!universe)
@@ -230,7 +231,7 @@ void OlaServerServiceImpl::PatchPort(
     RpcController* controller,
     const PatchPortRequest* request,
     Ack*,
-    google::protobuf::Closure* done) {
+    ola::rpc::RpcService::CompletionCallback* done) {
   ClosureRunner runner(done);
   AbstractDevice *device =
     m_device_manager->GetDevice(request->device_alias());
@@ -271,7 +272,7 @@ void OlaServerServiceImpl::SetPortPriority(
     RpcController* controller,
     const ola::proto::PortPriorityRequest* request,
     Ack*,
-    google::protobuf::Closure* done) {
+    ola::rpc::RpcService::CompletionCallback* done) {
   ClosureRunner runner(done);
   AbstractDevice *device =
     m_device_manager->GetDevice(request->device_alias());
@@ -283,7 +284,7 @@ void OlaServerServiceImpl::SetPortPriority(
 
   bool inherit_mode = true;
   uint8_t value = 0;
-  if (request->priority_mode() == PRIORITY_MODE_OVERRIDE) {
+  if (request->priority_mode() == PRIORITY_MODE_STATIC) {
     if (request->has_priority()) {
       inherit_mode = false;
       value = request->priority();
@@ -304,7 +305,7 @@ void OlaServerServiceImpl::SetPortPriority(
     if (inherit_mode)
       status = m_port_manager->SetPriorityInherit(port);
     else
-      status = m_port_manager->SetPriorityOverride(port, value);
+      status = m_port_manager->SetPriorityStatic(port, value);
   } else {
     InputPort *port = device->GetInputPort(request->port_id());
     if (!port)
@@ -313,7 +314,7 @@ void OlaServerServiceImpl::SetPortPriority(
     if (inherit_mode)
       status = m_port_manager->SetPriorityInherit(port);
     else
-      status = m_port_manager->SetPriorityOverride(port, value);
+      status = m_port_manager->SetPriorityStatic(port, value);
   }
 
   if (!status)
@@ -329,7 +330,7 @@ void OlaServerServiceImpl::GetUniverseInfo(
     RpcController* controller,
     const OptionalUniverseRequest* request,
     UniverseInfoReply* response,
-    google::protobuf::Closure* done) {
+    ola::rpc::RpcService::CompletionCallback* done) {
   ClosureRunner runner(done);
   UniverseInfo *universe_info;
 
@@ -374,7 +375,7 @@ void OlaServerServiceImpl::GetPlugins(
     RpcController*,
     const PluginListRequest*,
     PluginListReply* response,
-    google::protobuf::Closure* done) {
+    ola::rpc::RpcService::CompletionCallback* done) {
   ClosureRunner runner(done);
   vector<AbstractPlugin*> plugin_list;
   vector<AbstractPlugin*>::const_iterator iter;
@@ -394,7 +395,7 @@ void OlaServerServiceImpl::GetPluginDescription(
     RpcController* controller,
     const ola::proto::PluginDescriptionRequest* request,
     ola::proto::PluginDescriptionReply* response,
-    google::protobuf::Closure* done) {
+    ola::rpc::RpcService::CompletionCallback* done) {
   ClosureRunner runner(done);
   AbstractPlugin *plugin =
     m_plugin_manager->GetPlugin((ola_plugin_id) request->plugin_id());
@@ -415,7 +416,7 @@ void OlaServerServiceImpl::GetPluginState(
     RpcController* controller,
     const ola::proto::PluginStateRequest* request,
     ola::proto::PluginStateReply* response,
-    google::protobuf::Closure* done) {
+    ola::rpc::RpcService::CompletionCallback* done) {
   ClosureRunner runner(done);
   ola_plugin_id plugin_id = (ola_plugin_id) request->plugin_id();
   AbstractPlugin *plugin = m_plugin_manager->GetPlugin(plugin_id);
@@ -441,10 +442,11 @@ void OlaServerServiceImpl::GetPluginState(
 /*
  * Return information on available devices
  */
-void OlaServerServiceImpl::GetDeviceInfo(RpcController*,
-                                         const DeviceInfoRequest* request,
-                                         DeviceInfoReply* response,
-                                         google::protobuf::Closure* done) {
+void OlaServerServiceImpl::GetDeviceInfo(
+    RpcController*,
+    const DeviceInfoRequest* request,
+    DeviceInfoReply* response,
+    ola::rpc::RpcService::CompletionCallback* done) {
   ClosureRunner runner(done);
   vector<device_alias_pair> device_list = m_device_manager->Devices();
   vector<device_alias_pair>::const_iterator iter;
@@ -468,7 +470,7 @@ void OlaServerServiceImpl::GetCandidatePorts(
     RpcController* controller,
     const ola::proto::OptionalUniverseRequest* request,
     ola::proto::DeviceInfoReply* response,
-    google::protobuf::Closure* done) {
+    ola::rpc::RpcService::CompletionCallback* done) {
   ClosureRunner runner(done);
   vector<device_alias_pair> device_list = m_device_manager->Devices();
   vector<device_alias_pair>::const_iterator iter;
@@ -575,10 +577,11 @@ void OlaServerServiceImpl::GetCandidatePorts(
 /*
  * Handle a ConfigureDevice request
  */
-void OlaServerServiceImpl::ConfigureDevice(RpcController* controller,
-                                           const DeviceConfigRequest* request,
-                                           DeviceConfigReply* response,
-                                           google::protobuf::Closure* done) {
+void OlaServerServiceImpl::ConfigureDevice(
+    RpcController* controller,
+    const DeviceConfigRequest* request,
+    DeviceConfigReply* response,
+    ola::rpc::RpcService::CompletionCallback* done) {
   AbstractDevice *device =
     m_device_manager->GetDevice(request->device_alias());
   if (!device) {
@@ -587,8 +590,7 @@ void OlaServerServiceImpl::ConfigureDevice(RpcController* controller,
     return;
   }
 
-  device->Configure(controller,
-                    request->data(),
+  device->Configure(controller, request->data(),
                     response->mutable_data(), done);
 }
 
@@ -596,10 +598,11 @@ void OlaServerServiceImpl::ConfigureDevice(RpcController* controller,
 /*
  * Fetch the UID list for a universe
  */
-void OlaServerServiceImpl::GetUIDs(RpcController* controller,
-                                   const ola::proto::UniverseRequest* request,
-                                   ola::proto::UIDListReply* response,
-                                   google::protobuf::Closure* done) {
+void OlaServerServiceImpl::GetUIDs(
+    RpcController* controller,
+    const ola::proto::UniverseRequest* request,
+    ola::proto::UIDListReply* response,
+    ola::rpc::RpcService::CompletionCallback* done) {
   ClosureRunner runner(done);
   Universe *universe = m_universe_store->GetUniverse(request->universe());
   if (!universe)
@@ -612,8 +615,7 @@ void OlaServerServiceImpl::GetUIDs(RpcController* controller,
   UIDSet::Iterator iter = uid_set.Begin();
   for (; iter != uid_set.End(); ++iter) {
     ola::proto::UID *uid = response->add_uid();
-    uid->set_esta_id(iter->ManufacturerId());
-    uid->set_device_id(iter->DeviceId());
+    SetProtoUID(*iter, uid);
   }
 }
 
@@ -625,7 +627,7 @@ void OlaServerServiceImpl::ForceDiscovery(
     RpcController* controller,
     const ola::proto::DiscoveryRequest* request,
     ola::proto::UIDListReply *response,
-    google::protobuf::Closure* done) {
+    ola::rpc::RpcService::CompletionCallback* done) {
   Universe *universe = m_universe_store->GetUniverse(request->universe());
 
   if (universe) {
@@ -649,9 +651,9 @@ void OlaServerServiceImpl::ForceDiscovery(
  */
 void OlaServerServiceImpl::RDMCommand(
     RpcController* controller,
-    const ::ola::proto::RDMRequest* request,
+    const ola::proto::RDMRequest* request,
     ola::proto::RDMResponse* response,
-    google::protobuf::Closure* done,
+    ola::rpc::RpcService::CompletionCallback* done,
     const UID *uid,
     class Client *client) {
   Universe *universe = m_universe_store->GetUniverse(request->universe());
@@ -708,9 +710,9 @@ void OlaServerServiceImpl::RDMCommand(
  */
 void OlaServerServiceImpl::RDMDiscoveryCommand(
     RpcController* controller,
-    const ::ola::proto::RDMDiscoveryRequest* request,
+    const ola::proto::RDMDiscoveryRequest* request,
     ola::proto::RDMResponse* response,
-    google::protobuf::Closure* done,
+    ola::rpc::RpcService::CompletionCallback* done,
     const UID *uid,
     class Client *client) {
   Universe *universe = m_universe_store->GetUniverse(request->universe());
@@ -752,9 +754,9 @@ void OlaServerServiceImpl::RDMDiscoveryCommand(
  */
 void OlaServerServiceImpl::SetSourceUID(
     RpcController*,
-    const ::ola::proto::UID* request,
+    const ola::proto::UID* request,
     ola::proto::Ack*,
-    google::protobuf::Closure* done) {
+    ola::rpc::RpcService::CompletionCallback* done) {
   ClosureRunner runner(done);
   UID source_uid(request->esta_id(), request->device_id());
   m_uid = source_uid;
@@ -764,10 +766,11 @@ void OlaServerServiceImpl::SetSourceUID(
 /**
  * Send Timecode
  */
-void OlaServerServiceImpl::SendTimeCode(RpcController* controller,
-                                        const ::ola::proto::TimeCode* request,
-                                        ::ola::proto::Ack*,
-                                        ::google::protobuf::Closure* done) {
+void OlaServerServiceImpl::SendTimeCode(
+    RpcController* controller,
+    const ola::proto::TimeCode* request,
+    ola::proto::Ack*,
+    ola::rpc::RpcService::CompletionCallback* done) {
   ClosureRunner runner(done);
   ola::timecode::TimeCode time_code(
     static_cast<ola::timecode::TimeCodeType>(request->type()),
@@ -792,7 +795,7 @@ void OlaServerServiceImpl::SendTimeCode(RpcController* controller,
  */
 void OlaServerServiceImpl::HandleRDMResponse(
     ola::proto::RDMResponse* response,
-    google::protobuf::Closure* done,
+    ola::rpc::RpcService::CompletionCallback* done,
     bool include_raw_packets,
     ola::rdm::rdm_response_code code,
     const RDMResponse *rdm_response,
@@ -809,10 +812,13 @@ void OlaServerServiceImpl::HandleRDMResponse(
     } else {
       uint8_t response_type = rdm_response->ResponseType();
       if (response_type <= ola::rdm::RDM_NACK_REASON) {
+        SetProtoUID(rdm_response->SourceUID(), response->mutable_source_uid());
+        SetProtoUID(rdm_response->DestinationUID(),
+                    response->mutable_dest_uid());
+        response->set_transaction_number(rdm_response->TransactionNumber());
         response->set_response_type(
             static_cast<ola::proto::RDMResponseType>(response_type));
         response->set_message_count(rdm_response->MessageCount());
-        response->set_param_id(rdm_response->ParamId());
         response->set_sub_device(rdm_response->SubDevice());
 
         switch (rdm_response->CommandClass()) {
@@ -830,6 +836,8 @@ void OlaServerServiceImpl::HandleRDMResponse(
               rdm_response->CommandClass();
         }
 
+        response->set_param_id(rdm_response->ParamId());
+
         if (rdm_response->ParamData() && rdm_response->ParamDataSize()) {
           const string data(
               reinterpret_cast<const char*>(rdm_response->ParamData()),
@@ -864,7 +872,7 @@ void OlaServerServiceImpl::HandleRDMResponse(
  */
 void OlaServerServiceImpl::RDMDiscoveryComplete(
     unsigned int universe_id,
-    google::protobuf::Closure* done,
+    ola::rpc::RpcService::CompletionCallback* done,
     ola::proto::UIDListReply *response,
     const UIDSet &uids) {
   ClosureRunner runner(done);
@@ -873,8 +881,7 @@ void OlaServerServiceImpl::RDMDiscoveryComplete(
   UIDSet::Iterator iter = uids.Begin();
   for (; iter != uids.End(); ++iter) {
     ola::proto::UID *uid = response->add_uid();
-    uid->set_esta_id(iter->ManufacturerId());
-    uid->set_device_id(iter->DeviceId());
+    SetProtoUID(*iter, uid);
   }
 }
 
@@ -959,14 +966,21 @@ void OlaServerServiceImpl::PopulatePort(const PortClass &port,
     port_info->set_active(false);
   }
 
-  if (port.PriorityCapability() != CAPABILITY_NONE)
-    port_info->set_priority(port.GetPriority());
-  if (port.PriorityCapability() == CAPABILITY_FULL)
+  if (port.PriorityCapability() != CAPABILITY_NONE) {
     port_info->set_priority_mode(port.GetPriorityMode());
+    if (port.GetPriorityMode() == PRIORITY_MODE_STATIC) {
+      port_info->set_priority(port.GetPriority());
+    }
+  }
 
   port_info->set_supports_rdm(port.SupportsRDM());
 }
 
+void OlaServerServiceImpl::SetProtoUID(const ola::rdm::UID &uid,
+                                       ola::proto::UID *pb_uid) {
+  pb_uid->set_esta_id(uid.ManufacturerId());
+  pb_uid->set_device_id(uid.DeviceId());
+}
 
 // OlaClientService
 // ----------------------------------------------------------------------------
@@ -981,9 +995,9 @@ OlaClientService::~OlaClientService() {
  */
 void OlaClientService::SetSourceUID(
     RpcController* controller,
-    const ::ola::proto::UID* request,
+    const ola::proto::UID* request,
     ola::proto::Ack* response,
-    google::protobuf::Closure* done) {
+    ola::rpc::RpcService::CompletionCallback* done) {
 
   UID source_uid(request->esta_id(), request->device_id());
   if (!m_uid)
@@ -1002,5 +1016,5 @@ OlaClientService *OlaClientServiceFactory::New(
     Client *client,
     OlaServerServiceImpl *impl) {
   return new OlaClientService(client, impl);
-};
+}
 }  // namespace ola
