@@ -23,33 +23,32 @@
  */
 
 #include <cppunit/extensions/HelperMacros.h>
-#include <google/protobuf/stubs/common.h>
 #include <string>
 
-#include "common/rpc/SimpleRpcController.h"
+#include "common/rpc/RpcController.h"
 #include "ola/BaseTypes.h"
+#include "ola/Callback.h"
 #include "ola/Clock.h"
 #include "ola/DmxBuffer.h"
 #include "ola/ExportMap.h"
 #include "ola/Logging.h"
 #include "ola/rdm/UID.h"
+#include "ola/testing/TestUtils.h"
 #include "olad/Client.h"
 #include "olad/DeviceManager.h"
 #include "olad/OlaServerServiceImpl.h"
 #include "olad/PluginLoader.h"
 #include "olad/Universe.h"
 #include "olad/UniverseStore.h"
-#include "ola/testing/TestUtils.h"
 
-
-using google::protobuf::Closure;
-using google::protobuf::NewCallback;
+using ola::NewSingleCallback;
+using ola::SingleUseCallback0;
 using ola::DmxBuffer;
-using ola::OlaServerServiceImpl;
 using ola::OlaClientService;
+using ola::OlaServerServiceImpl;
 using ola::Universe;
 using ola::UniverseStore;
-using ola::rpc::SimpleRpcController;
+using ola::rpc::RpcController;
 using std::string;
 
 
@@ -62,7 +61,7 @@ class OlaServerServiceImplTest: public CppUnit::TestFixture {
   CPPUNIT_TEST(testSetMergeMode);
   CPPUNIT_TEST_SUITE_END();
 
-  public:
+ public:
     OlaServerServiceImplTest():
       m_uid(OPEN_LIGHTING_ESTA_CODE, 0) {
     }
@@ -77,29 +76,29 @@ class OlaServerServiceImplTest: public CppUnit::TestFixture {
     void testSetUniverseName();
     void testSetMergeMode();
 
-  private:
+ private:
     ola::rdm::UID m_uid;
     ola::Clock m_clock;
 
     void CallGetDmx(OlaServerServiceImpl *impl,
                     int universe_id,
-                    class GetDmxCheck &check);
+                    class GetDmxCheck *check);
     void CallRegisterForDmx(OlaClientService *service,
                             int universe_id,
                             ola::proto::RegisterAction action,
-                            class RegisterForDmxCheck &check);
+                            class RegisterForDmxCheck *check);
     void CallUpdateDmxData(OlaClientService *service,
                            int universe_id,
                            const DmxBuffer &data,
-                           class UpdateDmxDataCheck &check);
+                           class UpdateDmxDataCheck *check);
     void CallSetUniverseName(OlaClientService *service,
                              int universe_id,
                              const string &name,
-                             class SetUniverseNameCheck &check);
+                             class SetUniverseNameCheck *check);
     void CallSetMergeMode(OlaClientService *service,
                           int universe_id,
                           ola::proto::MergeMode merge_mode,
-                          class SetMergeModeCheck &check);
+                          class SetMergeModeCheck *check);
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(OlaServerServiceImplTest);
@@ -110,9 +109,9 @@ static const uint8_t SAMPLE_DMX_DATA[] = {1, 2, 3, 4, 5};
  * The GetDmx Checks
  */
 class GetDmxCheck {
-  public:
+ public:
     virtual ~GetDmxCheck() {}
-    virtual void Check(SimpleRpcController *controller,
+    virtual void Check(RpcController *controller,
                        ola::proto::DmxData *reply) = 0;
 };
 
@@ -121,8 +120,8 @@ class GetDmxCheck {
  * Assert that the data is all 0
  */
 class GetDmxNoDataCheck: public GetDmxCheck {
-  public:
-    void Check(SimpleRpcController *controller,
+ public:
+    void Check(RpcController *controller,
                ola::proto::DmxData *reply) {
       DmxBuffer empty_buffer;
       OLA_ASSERT_FALSE(controller->Failed());
@@ -135,8 +134,8 @@ class GetDmxNoDataCheck: public GetDmxCheck {
  * Assert that the data matches the test data.
  */
 class GetDmxValidDataCheck: public GetDmxCheck {
-  public:
-    void Check(SimpleRpcController *controller,
+ public:
+    void Check(RpcController *controller,
                ola::proto::DmxData *reply) {
       OLA_ASSERT_FALSE(controller->Failed());
       OLA_ASSERT(DmxBuffer(SAMPLE_DMX_DATA, sizeof(SAMPLE_DMX_DATA)) ==
@@ -149,9 +148,9 @@ class GetDmxValidDataCheck: public GetDmxCheck {
  * RegisterForDmxChecks
  */
 class RegisterForDmxCheck {
-  public:
+ public:
     virtual ~RegisterForDmxCheck() {}
-    virtual void Check(SimpleRpcController *controller,
+    virtual void Check(RpcController *controller,
                        ola::proto::Ack *reply) = 0;
 };
 
@@ -160,9 +159,9 @@ class RegisterForDmxCheck {
  * UpdateDmxDataCheck
  */
 class UpdateDmxDataCheck {
-  public:
+ public:
     virtual ~UpdateDmxDataCheck() {}
-    virtual void Check(SimpleRpcController *controller,
+    virtual void Check(RpcController *controller,
                        ola::proto::Ack *reply) = 0;
 };
 
@@ -171,9 +170,9 @@ class UpdateDmxDataCheck {
  * SetUniverseNameCheck
  */
 class SetUniverseNameCheck {
-  public:
+ public:
     virtual ~SetUniverseNameCheck() {}
-    virtual void Check(SimpleRpcController *controller,
+    virtual void Check(RpcController *controller,
                        ola::proto::Ack *reply) = 0;
 };
 
@@ -182,9 +181,9 @@ class SetUniverseNameCheck {
  * SetMergeModeCheck
  */
 class SetMergeModeCheck {
-  public:
+ public:
     virtual ~SetMergeModeCheck() {}
-    virtual void Check(SimpleRpcController *controller,
+    virtual void Check(RpcController *controller,
                        ola::proto::Ack *reply) = 0;
 };
 
@@ -194,8 +193,8 @@ class SetMergeModeCheck {
  */
 template<typename parent, typename reply>
 class GenericMissingUniverseCheck: public parent {
-  public:
-    void Check(SimpleRpcController *controller,
+ public:
+    void Check(RpcController *controller,
                reply *r) {
       OLA_ASSERT(controller->Failed());
       OLA_ASSERT_EQ(string("Universe doesn't exist"),
@@ -210,8 +209,8 @@ class GenericMissingUniverseCheck: public parent {
  */
 template<typename parent>
 class GenericAckCheck: public parent {
-  public:
-    void Check(SimpleRpcController *controller,
+ public:
+    void Check(RpcController *controller,
                ola::proto::Ack *r) {
       OLA_ASSERT_FALSE(controller->Failed());
       (void) r;
@@ -241,22 +240,22 @@ void OlaServerServiceImplTest::testGetDmx() {
 
   // test a universe that doesn't exist
   unsigned int universe_id = 0;
-  CallGetDmx(&impl, universe_id, missing_universe_check);
+  CallGetDmx(&impl, universe_id, &missing_universe_check);
 
   // test a new universe
   Universe *universe = store.GetUniverseOrCreate(universe_id);
   OLA_ASSERT(universe);
-  CallGetDmx(&impl, universe_id, empty_data_check);
+  CallGetDmx(&impl, universe_id, &empty_data_check);
 
   // Set the universe data
   DmxBuffer buffer(SAMPLE_DMX_DATA, sizeof(SAMPLE_DMX_DATA));
   universe->SetDMX(buffer);
-  CallGetDmx(&impl, universe_id, valid_data_check);
+  CallGetDmx(&impl, universe_id, &valid_data_check);
 
   // remove the universe and try again
   store.AddUniverseGarbageCollection(universe);
   store.GarbageCollectUniverses();
-  CallGetDmx(&impl, universe_id, missing_universe_check);
+  CallGetDmx(&impl, universe_id, &missing_universe_check);
 }
 
 
@@ -268,12 +267,12 @@ void OlaServerServiceImplTest::testGetDmx() {
  */
 void OlaServerServiceImplTest::CallGetDmx(OlaServerServiceImpl *impl,
                                           int universe_id,
-                                          GetDmxCheck &check) {
-  SimpleRpcController *controller = new SimpleRpcController();
+                                          GetDmxCheck *check) {
+  RpcController *controller = new RpcController();
   ola::proto::UniverseRequest *request = new ola::proto::UniverseRequest();
   ola::proto::DmxData *response = new ola::proto::DmxData();
-  Closure *closure = NewCallback(
-      &check,
+  SingleUseCallback0<void> *closure = NewSingleCallback(
+      check,
       &GetDmxCheck::Check,
       controller,
       response);
@@ -305,7 +304,7 @@ void OlaServerServiceImplTest::testRegisterForDmx() {
   unsigned int universe_id = 0;
   unsigned int second_universe_id = 99;
   GenericAckCheck<RegisterForDmxCheck> ack_check;
-  CallRegisterForDmx(&service, universe_id, ola::proto::REGISTER, ack_check);
+  CallRegisterForDmx(&service, universe_id, ola::proto::REGISTER, &ack_check);
 
   // The universe should exist now and the client should be bound
   Universe *universe = store.GetUniverse(universe_id);
@@ -314,30 +313,30 @@ void OlaServerServiceImplTest::testRegisterForDmx() {
   OLA_ASSERT_EQ((unsigned int) 1, universe->SinkClientCount());
 
   // Try to register again
-  CallRegisterForDmx(&service, universe_id, ola::proto::REGISTER, ack_check);
+  CallRegisterForDmx(&service, universe_id, ola::proto::REGISTER, &ack_check);
   OLA_ASSERT(universe->ContainsSinkClient(NULL));
   OLA_ASSERT_EQ((unsigned int) 1, universe->SinkClientCount());
 
   // Register a second universe
   CallRegisterForDmx(&service, second_universe_id, ola::proto::REGISTER,
-                     ack_check);
+                     &ack_check);
   Universe *second_universe = store.GetUniverse(universe_id);
   OLA_ASSERT(second_universe->ContainsSinkClient(NULL));
   OLA_ASSERT_EQ((unsigned int) 1, second_universe->SinkClientCount());
 
   // Unregister the first universe
-  CallRegisterForDmx(&service, universe_id, ola::proto::UNREGISTER, ack_check);
+  CallRegisterForDmx(&service, universe_id, ola::proto::UNREGISTER, &ack_check);
   OLA_ASSERT_FALSE(universe->ContainsSinkClient(NULL));
   OLA_ASSERT_EQ((unsigned int) 0, universe->SinkClientCount());
 
   // Unregister the second universe
   CallRegisterForDmx(&service, second_universe_id, ola::proto::UNREGISTER,
-                     ack_check);
+                     &ack_check);
   OLA_ASSERT_FALSE(second_universe->ContainsSinkClient(NULL));
   OLA_ASSERT_EQ((unsigned int) 0, second_universe->SinkClientCount());
 
   // Unregister again
-  CallRegisterForDmx(&service, universe_id, ola::proto::UNREGISTER, ack_check);
+  CallRegisterForDmx(&service, universe_id, ola::proto::UNREGISTER, &ack_check);
   OLA_ASSERT_FALSE(universe->ContainsSinkClient(NULL));
   OLA_ASSERT_EQ((unsigned int) 0, universe->SinkClientCount());
 }
@@ -354,13 +353,13 @@ void OlaServerServiceImplTest::CallRegisterForDmx(
     OlaClientService *service,
     int universe_id,
     ola::proto::RegisterAction action,
-    RegisterForDmxCheck &check) {
-  SimpleRpcController *controller = new SimpleRpcController();
+    RegisterForDmxCheck *check) {
+  RpcController *controller = new RpcController();
   ola::proto::RegisterDmxRequest *request = (
       new ola::proto::RegisterDmxRequest());
   ola::proto::Ack *response = new ola::proto::Ack();
-  Closure *closure = NewCallback(
-      &check,
+  SingleUseCallback0<void> *closure = NewSingleCallback(
+      check,
       &RegisterForDmxCheck::Check,
       controller,
       response);
@@ -402,28 +401,28 @@ void OlaServerServiceImplTest::testUpdateDmxData() {
 
   // Update a universe that doesn't exist
   m_clock.CurrentTime(&time1);
-  CallUpdateDmxData(&service1, universe_id, dmx_data, missing_universe_check);
+  CallUpdateDmxData(&service1, universe_id, dmx_data, &missing_universe_check);
   Universe *universe = store.GetUniverse(universe_id);
   OLA_ASSERT_FALSE(universe);
 
   // Update a universe that exists
   m_clock.CurrentTime(&time1);
   universe = store.GetUniverseOrCreate(universe_id);
-  CallUpdateDmxData(&service1, universe_id, dmx_data, ack_check);
+  CallUpdateDmxData(&service1, universe_id, dmx_data, &ack_check);
   OLA_ASSERT(dmx_data == universe->GetDMX());
 
   // Update a second client with an older timestamp
   // make sure we're in ltp mode
   OLA_ASSERT_EQ(universe->MergeMode(), Universe::MERGE_LTP);
   time1 = time1 - ola::TimeInterval(1000000);
-  CallUpdateDmxData(&service2, universe_id, dmx_data2, ack_check);
+  CallUpdateDmxData(&service2, universe_id, dmx_data2, &ack_check);
   OLA_ASSERT_EQ(dmx_data.Size(), universe->GetDMX().Size());
   // Should continue to hold the old data
   OLA_ASSERT(dmx_data == universe->GetDMX());
 
   // Now send a new update
   m_clock.CurrentTime(&time1);
-  CallUpdateDmxData(&service2, universe_id, dmx_data2, ack_check);
+  CallUpdateDmxData(&service2, universe_id, dmx_data2, &ack_check);
   OLA_ASSERT(dmx_data2 == universe->GetDMX());
 }
 
@@ -439,13 +438,13 @@ void OlaServerServiceImplTest::CallUpdateDmxData(
     OlaClientService *service,
     int universe_id,
     const DmxBuffer &data,
-    UpdateDmxDataCheck &check) {
-  SimpleRpcController *controller = new SimpleRpcController();
+    UpdateDmxDataCheck *check) {
+  RpcController *controller = new RpcController();
   ola::proto::DmxData *request = new
     ola::proto::DmxData();
   ola::proto::Ack *response = new ola::proto::Ack();
-  Closure *closure = NewCallback(
-      &check,
+  SingleUseCallback0<void> *closure = NewSingleCallback(
+      check,
       &UpdateDmxDataCheck::Check,
       controller,
       response);
@@ -484,17 +483,17 @@ void OlaServerServiceImplTest::testSetUniverseName() {
 
   // Check we get an error for a missing universe
   CallSetUniverseName(&service, universe_id, universe_name,
-                      missing_universe_check);
+                      &missing_universe_check);
   Universe *universe = store.GetUniverse(universe_id);
   OLA_ASSERT_FALSE(universe);
 
   // Check SetUniverseName works on an existing univserse
   universe = store.GetUniverseOrCreate(universe_id);
-  CallSetUniverseName(&service, universe_id, universe_name, ack_check);
+  CallSetUniverseName(&service, universe_id, universe_name, &ack_check);
   OLA_ASSERT_EQ(universe_name, universe->Name());
 
   // Run it again with a new name
-  CallSetUniverseName(&service, universe_id, universe_name2, ack_check);
+  CallSetUniverseName(&service, universe_id, universe_name2, &ack_check);
   OLA_ASSERT_EQ(universe_name2, universe->Name());
 }
 
@@ -510,13 +509,13 @@ void OlaServerServiceImplTest::CallSetUniverseName(
     OlaClientService *service,
     int universe_id,
     const string &name,
-    SetUniverseNameCheck &check) {
-  SimpleRpcController *controller = new SimpleRpcController();
+    SetUniverseNameCheck *check) {
+  RpcController *controller = new RpcController();
   ola::proto::UniverseNameRequest *request = new
     ola::proto::UniverseNameRequest();
   ola::proto::Ack *response = new ola::proto::Ack();
-  Closure *closure = NewCallback(
-      &check,
+  SingleUseCallback0<void> *closure = NewSingleCallback(
+      check,
       &SetUniverseNameCheck::Check,
       controller,
       response);
@@ -554,17 +553,17 @@ void OlaServerServiceImplTest::testSetMergeMode() {
 
   // Check we get an error for a missing universe
   CallSetMergeMode(&service, universe_id, ola::proto::HTP,
-                   missing_universe_check);
+                   &missing_universe_check);
   Universe *universe = store.GetUniverse(universe_id);
   OLA_ASSERT_FALSE(universe);
 
   // Check SetUniverseName works
   universe = store.GetUniverseOrCreate(universe_id);
-  CallSetMergeMode(&service, universe_id, ola::proto::HTP, ack_check);
+  CallSetMergeMode(&service, universe_id, ola::proto::HTP, &ack_check);
   OLA_ASSERT(Universe::MERGE_HTP == universe->MergeMode());
 
   // Run it again
-  CallSetMergeMode(&service, universe_id, ola::proto::LTP, ack_check);
+  CallSetMergeMode(&service, universe_id, ola::proto::LTP, &ack_check);
   OLA_ASSERT(Universe::MERGE_LTP == universe->MergeMode());
 }
 
@@ -580,13 +579,13 @@ void OlaServerServiceImplTest::CallSetMergeMode(
     OlaClientService *service,
     int universe_id,
     ola::proto::MergeMode merge_mode,
-    SetMergeModeCheck &check) {
-  SimpleRpcController *controller = new SimpleRpcController();
+    SetMergeModeCheck *check) {
+  RpcController *controller = new RpcController();
   ola::proto::MergeModeRequest *request = new
     ola::proto::MergeModeRequest();
   ola::proto::Ack *response = new ola::proto::Ack();
-  Closure *closure = NewCallback(
-      &check,
+  ola::SingleUseCallback0<void> *closure = NewSingleCallback(
+      check,
       &SetMergeModeCheck::Check,
       controller,
       response);
