@@ -15,7 +15,7 @@
  *
  * OladHTTPServer.cpp
  * Ola HTTP class
- * Copyright (C) 2005-2008 Simon Newton
+ * Copyright (C) 2005-2014 Simon Newton
  */
 
 #include <sys/time.h>
@@ -28,25 +28,35 @@
 #include "ola/DmxBuffer.h"
 #include "ola/Logging.h"
 #include "ola/StringUtils.h"
+#include "ola/base/Version.h"
+#include "ola/dmx/SourcePriorities.h"
 #include "ola/network/NetworkUtils.h"
 #include "ola/web/Json.h"
 #include "olad/DmxSource.h"
 #include "olad/HttpServerActions.h"
 #include "olad/OladHTTPServer.h"
 #include "olad/OlaServer.h"
-#include "olad/OlaVersion.h"
 
 
 namespace ola {
 
+using ola::client::OlaDevice;
+using ola::client::OlaInputPort;
+using ola::client::OlaOutputPort;
+using ola::client::OlaPlugin;
+using ola::client::OlaPort;
+using ola::client::OlaUniverse;
+using ola::http::HTTPRequest;
+using ola::http::HTTPResponse;
+using ola::http::HTTPServer;
 using ola::io::ConnectedDescriptor;
+using ola::web::JsonArray;
+using ola::web::JsonObject;
 using std::cout;
 using std::endl;
 using std::string;
 using std::stringstream;
 using std::vector;
-using ola::web::JsonArray;
-using ola::web::JsonObject;
 
 const char OladHTTPServer::HELP_PARAMETER[] = "help";
 const char OladHTTPServer::HELP_REDIRECTION[] = "?help=1";
@@ -60,7 +70,7 @@ const char OladHTTPServer::K_PRIORITY_MODE_SUFFIX[] = "_priority_mode";
  * @param export_map the ExportMap to display when /debug is called
  * @param client_socket A ConnectedDescriptor which is used to communicate with
  *   the server.
- * @param
+ * @param interface the network interface to bind to
  */
 OladHTTPServer::OladHTTPServer(ExportMap *export_map,
                                const OladHTTPServerOptions &options,
@@ -159,7 +169,7 @@ void OladHTTPServer::SetPidStore(const ola::rdm::RootPidStore *pid_store) {
 }
 
 
-/*
+/**
  * Print the server stats json
  * @param request the HTTPRequest
  * @param response the HTTPResponse
@@ -173,13 +183,12 @@ int OladHTTPServer::JsonServerStats(const HTTPRequest*,
   strftime(start_time_str, sizeof(start_time_str), "%c", &start_time);
 
   JsonObject json;
-  json.Add("hostname", ola::network::FullHostname());
+  json.Add("hostname", ola::network::FQDN());
   json.Add("ip", m_interface.ip_address.ToString());
   json.Add("broadcast", m_interface.bcast_address.ToString());
   json.Add("subnet", m_interface.subnet_mask.ToString());
-  json.Add("hw_address",
-      ola::network::HardwareAddressToString(m_interface.hw_address));
-  json.Add("version", OLA_VERSION);
+  json.Add("hw_address", m_interface.hw_address.ToString());
+  json.Add("version", ola::base::Version::GetVersion());
   json.Add("up_since", start_time_str);
   json.Add("quit_enabled", m_enable_quit);
 
@@ -191,21 +200,18 @@ int OladHTTPServer::JsonServerStats(const HTTPRequest*,
 }
 
 
-/*
+/**
  * Print the list of universes / plugins as a json string
  * @param request the HTTPRequest
  * @param response the HTTPResponse
  * @returns MHD_NO or MHD_YES
  */
 int OladHTTPServer::JsonUniversePluginList(const HTTPRequest*,
-                                          HTTPResponse *response) {
-  bool ok = m_client.FetchPluginList(
+                                           HTTPResponse *response) {
+  m_client.FetchPluginList(
       NewSingleCallback(this,
                         &OladHTTPServer::HandlePluginList,
                         response));
-
-  if (!ok)
-    return m_server.ServeError(response, K_BACKEND_DISCONNECTED_ERROR);
   return MHD_YES;
 }
 
@@ -225,14 +231,11 @@ int OladHTTPServer::JsonPluginInfo(const HTTPRequest *request,
   if (!StringToInt(val, &plugin_id))
     return ServeHelpRedirect(response);
 
-  bool ok = m_client.FetchPluginDescription(
+  m_client.FetchPluginDescription(
       (ola_plugin_id) plugin_id,
       NewSingleCallback(this,
                         &OladHTTPServer::HandlePartialPluginInfo,
                         response, plugin_id));
-
-  if (!ok)
-    return m_server.ServeError(response, K_BACKEND_DISCONNECTED_ERROR);
   return MHD_YES;
 }
 
@@ -252,14 +255,12 @@ int OladHTTPServer::JsonUniverseInfo(const HTTPRequest *request,
   if (!StringToInt(uni_id, &universe_id))
     return ServeHelpRedirect(response);
 
-  bool ok = m_client.FetchUniverseInfo(
+  m_client.FetchUniverseInfo(
       universe_id,
       NewSingleCallback(this,
                         &OladHTTPServer::HandleUniverseInfo,
                         response));
 
-  if (!ok)
-    return m_server.ServeError(response, K_BACKEND_DISCONNECTED_ERROR);
   return MHD_YES;
   (void) request;
 }
@@ -276,11 +277,10 @@ int OladHTTPServer::JsonAvailablePorts(const HTTPRequest *request,
   if (request->CheckParameterExists(HELP_PARAMETER))
     return ServeUsage(response, "? or ?id=[universe]");
   string uni_id = request->GetParameter("id");
-  bool ok = false;
 
   if (uni_id.empty()) {
     // get all available ports
-    ok = m_client.FetchCandidatePorts(
+    m_client.FetchCandidatePorts(
         NewSingleCallback(this,
                           &OladHTTPServer::HandleCandidatePorts,
                           response));
@@ -289,20 +289,17 @@ int OladHTTPServer::JsonAvailablePorts(const HTTPRequest *request,
     if (!StringToInt(uni_id, &universe_id))
       return ServeHelpRedirect(response);
 
-    ok = m_client.FetchCandidatePorts(
+    m_client.FetchCandidatePorts(
         universe_id,
         NewSingleCallback(this,
                           &OladHTTPServer::HandleCandidatePorts,
                           response));
   }
-
-  if (!ok)
-    return m_server.ServeError(response, K_BACKEND_DISCONNECTED_ERROR);
   return MHD_YES;
 }
 
 
-/*
+/**
  * Create a new universe by binding one or more ports.
  * @param request the HTTPRequest
  * @param response the HTTPResponse
@@ -331,8 +328,7 @@ int OladHTTPServer::CreateNewUniverse(const HTTPRequest *request,
 
   // add patch actions here
   string add_port_ids = request->GetPostParameter("add_ports");
-  AddPatchActions(action_queue, add_port_ids, universe_id, PATCH);
-
+  AddPatchActions(action_queue, add_port_ids, universe_id, ola::client::PATCH);
 
   if (!name.empty())
     action_queue->AddAction(
@@ -343,7 +339,7 @@ int OladHTTPServer::CreateNewUniverse(const HTTPRequest *request,
 }
 
 
-/*
+/**
  * Modify an existing universe.
  * @param request the HTTPRequest
  * @param response the HTTPResponse
@@ -384,10 +380,10 @@ int OladHTTPServer::ModifyUniverse(const HTTPRequest *request,
   }
 
   string remove_port_ids = request->GetPostParameter("remove_ports");
-  AddPatchActions(action_queue, remove_port_ids, universe_id, UNPATCH);
+  AddPatchActions(action_queue, remove_port_ids, universe_id, client::UNPATCH);
 
   string add_port_ids = request->GetPostParameter("add_ports");
-  AddPatchActions(action_queue, add_port_ids, universe_id, PATCH);
+  AddPatchActions(action_queue, add_port_ids, universe_id, client::PATCH);
 
   AddPriorityActions(action_queue, request);
 
@@ -396,8 +392,8 @@ int OladHTTPServer::ModifyUniverse(const HTTPRequest *request,
 }
 
 
-/*
- * Handle the get dmx command
+/**
+ * Handle the get DMX command
  * @param request the HTTPRequest
  * @param response the HTTPResponse
  * @returns MHD_NO or MHD_YES
@@ -410,20 +406,16 @@ int OladHTTPServer::GetDmx(const HTTPRequest *request,
   unsigned int universe_id;
   if (!StringToInt(uni_id, &universe_id))
     return ServeHelpRedirect(response);
-  int ok = m_client.FetchDmx(universe_id,
-                             NewSingleCallback(this,
-                                               &OladHTTPServer::HandleGetDmx,
-                                               response));
-
-  if (!ok)
-    return m_server.ServeError(response, K_BACKEND_DISCONNECTED_ERROR);
 
+  m_client.FetchDMX(
+      universe_id,
+      NewSingleCallback(this, &OladHTTPServer::HandleGetDmx, response));
   return MHD_YES;
 }
 
 
-/*
- * Handle the set dmx command
+/**
+ * Handle the set DMX command
  * @param request the HTTPRequest
  * @param response the HTTPResponse
  * @returns MHD_NO or MHD_YES
@@ -444,18 +436,14 @@ int OladHTTPServer::HandleSetDmx(const HTTPRequest *request,
   if (!buffer.Size())
     return m_server.ServeError(response, "Invalid DMX string");
 
-  bool ok = m_client.SendDmx(
-      universe_id,
-      buffer,
+  ola::client::SendDMXArgs args(
       NewSingleCallback(this, &OladHTTPServer::HandleBoolResponse, response));
-
-  if (!ok)
-    return m_server.ServeError(response, K_BACKEND_DISCONNECTED_ERROR);
+  m_client.SendDMX(universe_id, buffer, args);
   return MHD_YES;
 }
 
 
-/*
+/**
  * Cause the server to shutdown
  * @param request the HTTPRequest
  * @param response the HTTPResponse
@@ -480,7 +468,7 @@ int OladHTTPServer::DisplayQuit(const HTTPRequest *request,
 }
 
 
-/*
+/**
  * Reload all plugins
  * @param request the HTTPRequest
  * @param response the HTTPResponse
@@ -499,8 +487,8 @@ int OladHTTPServer::ReloadPlugins(const HTTPRequest *request,
 }
 
 
-/*
- * Reload the Pid Store.
+/**
+ * Reload the PID Store.
  * @param request the HTTPRequest
  * @param response the HTTPResponse
  * @returns MHD_NO or MHD_YES
@@ -518,17 +506,16 @@ int OladHTTPServer::ReloadPidStore(const HTTPRequest *request,
 }
 
 
-/*
+/**
  * Handle the plugin list callback
  * @param response the HTTPResponse that is associated with the request.
  * @param plugins a list of plugins
- * @param error an error string.
  */
 void OladHTTPServer::HandlePluginList(HTTPResponse *response,
-                                     const vector<OlaPlugin> &plugins,
-                                     const string &error) {
-  if (!error.empty()) {
-    m_server.ServeError(response, error);
+                                      const client::Result &result,
+                                      const vector<OlaPlugin> &plugins) {
+  if (!result.Success()) {
+    m_server.ServeError(response, result.Error());
     return;
   }
 
@@ -536,18 +523,12 @@ void OladHTTPServer::HandlePluginList(HTTPResponse *response,
 
   // fire off the universe request now. the main server is running in a
   // separate thread.
-  bool ok = m_client.FetchUniverseList(
+  m_client.FetchUniverseList(
       NewSingleCallback(this,
                         &OladHTTPServer::HandleUniverseList,
                         response,
                         json));
 
-  if (!ok) {
-    m_server.ServeError(response, K_BACKEND_DISCONNECTED_ERROR);
-    delete json;
-    return;
-  }
-
   JsonArray *plugins_json = json->AddArray("plugins");
   vector<OlaPlugin>::const_iterator iter;
   for (iter = plugins.begin(); iter != plugins.end(); ++iter) {
@@ -558,17 +539,15 @@ void OladHTTPServer::HandlePluginList(HTTPResponse *response,
 }
 
 
-/*
+/**
  * Handle the universe list callback
  * @param response the HTTPResponse that is associated with the request.
- * @param plugins a list of plugins
- * @param error an error string.
  */
 void OladHTTPServer::HandleUniverseList(HTTPResponse *response,
                                        JsonObject *json,
-                                       const vector<OlaUniverse> &universes,
-                                       const string &error) {
-  if (error.empty()) {
+                                       const client::Result &result,
+                                       const vector<OlaUniverse> &universes) {
+  if (result.Success()) {
     JsonArray *universe_json = json->AddArray("universes");
 
     vector<OlaUniverse>::const_iterator iter;
@@ -590,50 +569,48 @@ void OladHTTPServer::HandleUniverseList(HTTPResponse *response,
 }
 
 
-/*
+/**
  * Handle the plugin description response.
  * @param response the HTTPResponse that is associated with the request.
+ * @param plugin_id the plugin id.
  * @param description the plugin description.
- * @param error an error string.
  */
 void OladHTTPServer::HandlePartialPluginInfo(HTTPResponse *response,
                                              int plugin_id,
-                                             const string &description,
-                                             const string &error) {
-  if (!error.empty()) {
-    m_server.ServeError(response, error);
+                                             const client::Result &result,
+                                             const string &description) {
+  if (!result.Success()) {
+    m_server.ServeError(response, result.Error());
     return;
   }
-  bool ok = m_client.FetchPluginState(
+  m_client.FetchPluginState(
       (ola_plugin_id) plugin_id,
       NewSingleCallback(this,
                         &OladHTTPServer::HandlePluginInfo,
                         response, description));
-
-  if (!ok)
-    m_server.ServeError(response, K_BACKEND_DISCONNECTED_ERROR);
 }
 
-/*
+/**
  * Handle the plugin description response.
  * @param response the HTTPResponse that is associated with the request.
  * @param description the plugin description.
- * @param error an error string.
+ * @param state the state of the plugin.
  */
-void OladHTTPServer::HandlePluginInfo(
-    HTTPResponse *response,
-    string description,
-    const OlaCallbackClient::PluginState &state,
-    const string &error) {
-  if (!error.empty()) {
-    m_server.ServeError(response, error);
+void OladHTTPServer::HandlePluginInfo(HTTPResponse *response,
+                                      string description,
+                                      const client::Result &result,
+                                      const ola::client::PluginState &state) {
+  if (!result.Success()) {
+    m_server.ServeError(response, result.Error());
     return;
   }
+
   string escaped_description = description;
-  Escape(&escaped_description);
+  // Replace \n before passing in so we get \\n out the far end
+  ReplaceAll(&escaped_description, "\n", "\\n");
 
   JsonObject json;
-  json.Add("description", description);
+  json.Add("description", escaped_description);
   json.Add("name", state.name);
   json.Add("enabled", state.enabled);
   json.Add("active", state.active);
@@ -654,17 +631,16 @@ void OladHTTPServer::HandlePluginInfo(
 }
 
 
-/*
+/**
  * Handle the universe info
  * @param response the HTTPResponse that is associated with the request.
  * @param universe the OlaUniverse object
- * @param error an error string.
  */
 void OladHTTPServer::HandleUniverseInfo(HTTPResponse *response,
-                                       OlaUniverse &universe,
-                                       const string &error) {
-  if (!error.empty()) {
-    m_server.ServeError(response, error);
+                                        const client::Result &result,
+                                        const OlaUniverse &universe) {
+  if (!result.Success()) {
+    m_server.ServeError(response, result.Error());
     return;
   }
 
@@ -672,7 +648,7 @@ void OladHTTPServer::HandleUniverseInfo(HTTPResponse *response,
 
   // fire off the device/port request now. the main server is running in a
   // separate thread.
-  bool ok = m_client.FetchDeviceInfo(
+  m_client.FetchDeviceInfo(
       ola::OLA_PLUGIN_ALL,
       NewSingleCallback(this,
                         &OladHTTPServer::HandlePortsForUniverse,
@@ -680,12 +656,6 @@ void OladHTTPServer::HandleUniverseInfo(HTTPResponse *response,
                         json,
                         universe.Id()));
 
-  if (!ok) {
-    m_server.ServeError(response, K_BACKEND_DISCONNECTED_ERROR);
-    delete json;
-    return;
-  }
-
   json->Add("id", universe.Id());
   json->Add("name", universe.Name());
   json->Add("merge_mode",
@@ -697,9 +667,9 @@ void OladHTTPServer::HandlePortsForUniverse(
     HTTPResponse *response,
     JsonObject *json,
     unsigned int universe_id,
-    const vector<OlaDevice> &devices,
-    const string &error) {
-  if (error.empty()) {
+    const client::Result &result,
+    const vector<OlaDevice> &devices) {
+  if (result.Success()) {
     vector<OlaDevice>::const_iterator iter = devices.begin();
     vector<OlaInputPort>::const_iterator input_iter;
     vector<OlaOutputPort>::const_iterator output_iter;
@@ -737,18 +707,17 @@ void OladHTTPServer::HandlePortsForUniverse(
 }
 
 
-/*
+/**
  * Handle the list of candidate ports
  * @param response the HTTPResponse that is associated with the request.
  * @param devices the possbile devices & ports
- * @param error an error string.
  */
 void OladHTTPServer::HandleCandidatePorts(
     HTTPResponse *response,
-    const vector<class OlaDevice> &devices,
-    const string &error) {
-  if (!error.empty()) {
-    m_server.ServeError(response, error);
+    const client::Result &result,
+    const vector<OlaDevice> &devices) {
+  if (!result.Success()) {
+    m_server.ServeError(response, result.Error());
     return;
   }
 
@@ -845,7 +814,7 @@ void OladHTTPServer::ModifyUniverseComplete(HTTPResponse *response,
  * Send the response to a modify universe request.
  */
 void OladHTTPServer::SendModifyUniverseResponse(HTTPResponse *response,
-                                               ActionQueue *action_queue) {
+                                                ActionQueue *action_queue) {
   if (!action_queue->WasSuccessful()) {
     delete action_queue;
     m_server.ServeError(response, "Update failed");
@@ -858,7 +827,7 @@ void OladHTTPServer::SendModifyUniverseResponse(HTTPResponse *response,
   }
 }
 
-/*
+/**
  * Serve usage information.
  * @param response the reponse to use.
  * @param details the usage information
@@ -876,21 +845,21 @@ int OladHTTPServer::ServeUsage(HTTPResponse *response, const string &details) {
   return r;
 }
 
-/*
+/**
  * Callback for m_client.FetchDmx called by GetDmx
  * @param response the HTTPResponse
  * @param buffer the DmxBuffer
- * @param error Error message
  */
 void OladHTTPServer::HandleGetDmx(HTTPResponse *response,
-                                 const DmxBuffer &buffer,
-                                 const string &error) {
+                                  const client::Result &result,
+                                  const client::DMXMetadata &,
+                                  const DmxBuffer &buffer) {
   // rather than adding 512 JsonValue we cheat and use raw here
   stringstream str;
   str << "[" << buffer.ToString() << "]";
   JsonObject json;
   json.AddRaw("dmx", str.str());
-  json.Add("error", error);
+  json.Add("error", result.Error());
 
   response->SetNoCache();
   response->SetContentType(HTTPServer::CONTENT_TYPE_PLAIN);
@@ -899,15 +868,14 @@ void OladHTTPServer::HandleGetDmx(HTTPResponse *response,
 }
 
 
-/*
+/**
  * Handle the set DMX response.
  * @param response the HTTPResponse that is associated with the request.
- * @param error an error string.
  */
 void OladHTTPServer::HandleBoolResponse(HTTPResponse *response,
-                                       const string &error) {
-  if (!error.empty()) {
-    m_server.ServeError(response, error);
+                                        const client::Result &result) {
+  if (!result.Success()) {
+    m_server.ServeError(response, result.Error());
     return;
   }
   response->SetContentType(HTTPServer::CONTENT_TYPE_PLAIN);
@@ -932,17 +900,27 @@ void OladHTTPServer::PortToJson(JsonObject *json,
   json->Add("id", str.str());
   json->Add("is_output", is_output);
 
+  JsonObject *priority_json = json->AddObject("priority");
   if (port.PriorityCapability() != CAPABILITY_NONE) {
-    JsonObject *priority_json = json->AddObject("priority");
-    priority_json->Add("value", static_cast<int>(port.Priority()));
+    // This can be used as the default value for the priority input and because
+    // inherit ports can return a 0 priority we shall set it to the default
+    // here
+    uint8_t priority = port.Priority();
+    if (priority == 0) {
+      // We check here because 0 is an invalid priority outside of Olad
+      priority = dmx::SOURCE_PRIORITY_DEFAULT;
+    }
+    priority_json->Add("value", static_cast<int>(priority));
     priority_json->Add(
       "current_mode",
-      (port.PriorityMode() == PRIORITY_MODE_INHERIT ?  "inherit" : "override"));
+      (port.PriorityMode() == PRIORITY_MODE_INHERIT ?  "inherit" : "static"));
+    priority_json->Add("priority_capability",
+      (port.PriorityCapability() == CAPABILITY_STATIC ? "static" : "full"));
   }
 }
 
 
-/*
+/**
  * Add the Patch Actions to the ActionQueue.
  * @param action_queue the ActionQueue to add the actions to.
  * @param port_id_string a string to ports to add/remove.
@@ -952,7 +930,7 @@ void OladHTTPServer::PortToJson(JsonObject *json,
 void OladHTTPServer::AddPatchActions(ActionQueue *action_queue,
                                     const string port_id_string,
                                     unsigned int universe,
-                                    PatchAction port_action) {
+                                    client::PatchAction port_action) {
   vector<port_identifier> ports;
   vector<port_identifier>::const_iterator iter;
   DecodePortIds(port_id_string, &ports);
@@ -969,7 +947,7 @@ void OladHTTPServer::AddPatchActions(ActionQueue *action_queue,
 }
 
 
-/*
+/**
  * Add the Priority Actions to the ActionQueue.
  * @param action_queue the ActionQueue to add the actions to.
  * @param request the HTTPRequest to read the url params from.
@@ -986,18 +964,18 @@ void OladHTTPServer::AddPriorityActions(ActionQueue *action_queue,
     string priority_id = iter->string_id + K_PRIORITY_VALUE_SUFFIX;
     string mode = request->GetPostParameter(priority_mode_id);
 
-    if (mode == "0") {
+    if (mode == "inherit") {
       action_queue->AddAction(new PortPriorityInheritAction(
         &m_client,
         iter->device_alias,
         iter->port,
         iter->direction));
-    } else if (mode == "1" || mode == "") {
+    } else if (mode == "static" || mode == "") {
       // an empty mode param means this is a static port
       string value = request->GetPostParameter(priority_id);
       uint8_t priority_value;
       if (StringToInt(value, &priority_value)) {
-        action_queue->AddAction(new PortPriorityOverrideAction(
+        action_queue->AddAction(new PortPriorityStaticAction(
           &m_client,
           iter->device_alias,
           iter->port,
@@ -1009,7 +987,7 @@ void OladHTTPServer::AddPriorityActions(ActionQueue *action_queue,
 }
 
 
-/*
+/**
  * Decode port ids in a string.
  * This converts a string like "4-I-1,2-O-3" into a vector of port identifiers.
  * @param port_ids the port ids in a , separated string
@@ -1041,14 +1019,15 @@ void OladHTTPServer::DecodePortIds(const string &port_ids,
       continue;
     }
 
-    PortDirection direction = tokens[1] == "I" ? INPUT_PORT : OUTPUT_PORT;
+    client::PortDirection direction = (
+        tokens[1] == "I" ?  client::INPUT_PORT : client::OUTPUT_PORT);
     port_identifier port_id = {device_alias, port, direction, *iter};
     ports->push_back(port_id);
   }
 }
 
 
-/*
+/**
  * Register a handler
  */
 inline void OladHTTPServer::RegisterHandler(
