@@ -23,10 +23,12 @@
 
 #include <vector>
 
+#include "ola/base/Macro.h"
+
 namespace ola {
 
 class PluginLoader {
-  public:
+ public:
     PluginLoader() {}
     virtual ~PluginLoader() {}
 
@@ -36,8 +38,11 @@ class PluginLoader {
     virtual std::vector<class AbstractPlugin*> LoadPlugins() = 0;
     virtual void UnloadPlugins() = 0;
 
-  protected:
+ protected:
     class PluginAdaptor *m_plugin_adaptor;
+
+ private:
+    DISALLOW_COPY_AND_ASSIGN(PluginLoader);
 };
 }  // namespace ola
 #endif  // OLAD_PLUGINLOADER_H_
