@@ -51,6 +51,14 @@
 
 namespace ola {
 
+using ola::rdm::RDMDiscoveryCallback;
+using ola::rdm::UID;
+using std::map;
+using std::set;
+using std::string;
+using std::stringstream;
+using std::vector;
+
 const char Universe::K_UNIVERSE_UID_COUNT_VAR[] = "universe-uids";
 const char Universe::K_FPS_VAR[] = "universe-dmx-frames";
 const char Universe::K_MERGE_HTP_STR[] = "htp";
@@ -75,7 +83,7 @@ Universe::Universe(unsigned int universe_id, UniverseStore *store,
                    Clock *clock)
     : m_universe_name(""),
       m_universe_id(universe_id),
-      m_active_priority(DmxSource::PRIORITY_MIN),
+      m_active_priority(ola::dmx::SOURCE_PRIORITY_MIN),
       m_merge_mode(Universe::MERGE_LTP),
       m_universe_store(store),
       m_export_map(export_map),
@@ -664,7 +672,7 @@ bool Universe::MergeAll(const InputPort *port, const Client *client) {
   vector<InputPort*>::const_iterator iter;
   SourceClientMap::const_iterator client_iter;
 
-  m_active_priority = DmxSource::PRIORITY_MIN;
+  m_active_priority = ola::dmx::SOURCE_PRIORITY_MIN;
   TimeStamp now;
   m_clock->CurrentTime(&now);
   bool changed_source_is_active = false;
