@@ -52,9 +52,17 @@ using ola::network::LittleEndianToHost;
 using ola::network::NetworkToHost;
 using ola::network::UDPSocket;
 using ola::rdm::RDMDiscoveryCallback;
+using ola::rdm::RDMCallback;
+using ola::rdm::RDMCommand;
 using ola::rdm::RDMCommandSerializer;
+using ola::rdm::RDMRequest;
+using ola::rdm::RDMResponse;
+using ola::rdm::UID;
+using ola::rdm::UIDSet;
 using std::auto_ptr;
+using std::map;
 using std::pair;
+using std::set;
 using std::string;
 using std::vector;
 
@@ -68,7 +76,7 @@ typedef map<UID, std::pair<IPV4Address, uint8_t> > uid_map;
 
 // Input ports are ones that send data using ArtNet
 class ArtNetNodeImpl::InputPort {
-  public:
+ public:
     InputPort()
         : enabled(false),
           sequence_number(0),
@@ -123,7 +131,7 @@ class ArtNetNodeImpl::InputPort {
     void RunTodCallback() {
       if (m_tod_callback.get())
         RunRDMCallbackWithUIDs(uids, m_tod_callback.get());
-    };
+    }
 
     void RunDiscoveryCallback() {
       if (discovery_callback) {
@@ -157,7 +165,7 @@ class ArtNetNodeImpl::InputPort {
     // these control the sending of RDM requests.
     ola::thread::timeout_id rdm_send_timeout;
 
-  private:
+ private:
     uint8_t m_port_address;
     // The callback to run if we receive an TOD and the discovery process
     // isn't running
@@ -1040,8 +1048,7 @@ bool ArtNetNodeImpl::SendPollReply(const IPV4Address &destination) {
     packet.data.reply.sw_out[i] = m_output_ports[i].universe_address;
   }
   packet.data.reply.style = NODE_CODE;
-  memcpy(packet.data.reply.mac, m_interface.hw_address,
-         ola::network::MAC_LENGTH);
+  m_interface.hw_address.Get(packet.data.reply.mac);
   m_interface.ip_address.Get(packet.data.reply.bind_ip);
   // maybe set status2 here if the web UI is enabled
   packet.data.reply.status2 = 0x08;  // node supports 15 bit port addresses
@@ -1738,7 +1745,7 @@ void ArtNetNodeImpl::UpdatePortFromSource(OutputPort *port,
 
 
 /*
- * Check the version number of a incomming packet
+ * Check the version number of a incoming packet
  */
 bool ArtNetNodeImpl::CheckPacketVersion(const IPV4Address &source_address,
                                         const string &packet_type,
