@@ -30,6 +30,7 @@
 #include "ola/rdm/DimmerResponder.h"
 #include "ola/rdm/DummyResponder.h"
 #include "ola/rdm/MovingLightResponder.h"
+#include "ola/rdm/NetworkResponder.h"
 #include "ola/rdm/SensorResponder.h"
 #include "ola/rdm/UIDAllocator.h"
 #include "ola/rdm/UIDSet.h"
@@ -41,9 +42,16 @@ namespace ola {
 namespace plugin {
 namespace dummy {
 
-using std::auto_ptr;
 using ola::rdm::DimmerResponder;
 using ola::rdm::DummyResponder;
+using ola::rdm::RDMDiscoveryCallback;
+using ola::rdm::UID;
+using std::auto_ptr;
+using std::map;
+using std::string;
+using std::stringstream;
+using std::vector;
+
 
 /**
  * A count number of responders of type T.
@@ -65,10 +73,9 @@ void AddResponders(map<UID, ola::rdm::RDMControllerInterface*> *responders,
 /**
  * Create a new DummyPort
  * @param parent the parent device for this port
+ * @param options the config for the DummyPort such as the number of fake RDM
+ * devices to create
  * @param id the ID of this port
- * @param device_count the number of fake RDM devices to create
- * @param subdevice_count the number of subdevices each fake device should
- *   have.
  */
 DummyPort::DummyPort(DummyDevice *parent,
                      const Options &options,
@@ -105,6 +112,8 @@ DummyPort::DummyPort(DummyDevice *parent,
       &m_responders, &allocator, options.number_of_advanced_dimmers);
   AddResponders<ola::rdm::SensorResponder>(
       &m_responders, &allocator, options.number_of_sensor_responders);
+  AddResponders<ola::rdm::NetworkResponder>(
+      &m_responders, &allocator, options.number_of_network_responders);
 }
 
 
@@ -118,7 +127,7 @@ bool DummyPort::WriteDMX(const DmxBuffer &buffer,
   (void) priority;
   m_buffer = buffer;
   stringstream str;
-  std::string data = buffer.Get();
+  string data = buffer.Get();
 
   str << "Dummy port: got " << buffer.Size() << " bytes: ";
   for (unsigned int i = 0; i < 10 && i < data.size(); i++)
@@ -168,7 +177,7 @@ void DummyPort::SendRDMRequest(const ola::rdm::RDMRequest *request,
       if (i != m_responders.end()) {
         i->second->SendRDMRequest(request, callback);
       } else {
-          std::vector<std::string> packets;
+          std::vector<string> packets;
           callback->Run(ola::rdm::RDM_UNKNOWN_UID, NULL, packets);
           delete request;
       }
@@ -189,7 +198,7 @@ void DummyPort::RunDiscovery(RDMDiscoveryCallback *callback) {
 void DummyPort::HandleBroadcastAck(broadcast_request_tracker *tracker,
                                    ola::rdm::rdm_response_code code,
                                    const ola::rdm::RDMResponse *response,
-                                   const std::vector<std::string> &packets) {
+                                   const vector<string> &packets) {
   tracker->current_count++;
   if (code != ola::rdm::RDM_WAS_BROADCAST)
     tracker->failed = true;
