@@ -37,6 +37,13 @@ namespace ola {
 namespace plugin {
 namespace spi {
 
+using ola::rdm::UID;
+using std::auto_ptr;
+using std::set;
+using std::string;
+using std::stringstream;
+using std::vector;
+
 const char SPIDevice::SPI_DEVICE_NAME[] = "SPI Device";
 const char SPIDevice::HARDWARE_BACKEND[] = "hardware";
 const char SPIDevice::SOFTWARE_BACKEND[] = "software";
@@ -211,12 +218,13 @@ void SPIDevice::SetDefaults() {
   set<string> valid_backends;
   valid_backends.insert(HARDWARE_BACKEND);
   valid_backends.insert(SOFTWARE_BACKEND);
-  m_preferences->SetDefaultValue(SPIBackendKey(), SetValidator(valid_backends),
+  m_preferences->SetDefaultValue(SPIBackendKey(),
+                                 SetValidator<string>(valid_backends),
                                  SOFTWARE_BACKEND);
-  m_preferences->SetDefaultValue(SPISpeedKey(), IntValidator(0, 32000000),
-                                 "100000");
+  m_preferences->SetDefaultValue(SPISpeedKey(), UIntValidator(0, 32000000),
+                                 "1000000");
   m_preferences->SetDefaultValue(SPICEKey(), BoolValidator(), "false");
-  m_preferences->SetDefaultValue(PortCountKey(), IntValidator(1, 8), "1");
+  m_preferences->SetDefaultValue(PortCountKey(), UIntValidator(1, 8), "1");
   m_preferences->SetDefaultValue(SyncPortKey(), IntValidator(-2, 8), "0");
 }
 
