@@ -39,6 +39,8 @@
 #include "ola/rdm/RDMCommand.h"
 #include "ola/rdm/RDMEnums.h"
 #include "ola/rdm/ResponderHelper.h"
+#include "ola/rdm/ResponderLoadSensor.h"
+#include "ola/rdm/ResponderSensor.h"
 #include "ola/rdm/UID.h"
 #include "ola/rdm/UIDSet.h"
 #include "ola/stl/STLUtils.h"
@@ -52,8 +54,12 @@ namespace spi {
 
 using ola::network::HostToNetwork;
 using ola::network::NetworkToHost;
+using ola::rdm::LoadSensor;
 using ola::rdm::NR_DATA_OUT_OF_RANGE;
 using ola::rdm::NR_FORMAT_ERROR;
+using ola::rdm::Personality;
+using ola::rdm::PersonalityCollection;
+using ola::rdm::PersonalityManager;
 using ola::rdm::RDMCallback;
 using ola::rdm::RDMCommand;
 using ola::rdm::RDMRequest;
@@ -63,12 +69,23 @@ using ola::rdm::UID;
 using ola::rdm::UIDSet;
 using std::auto_ptr;
 using std::min;
+using std::string;
 
 const uint16_t SPIOutput::SPI_DELAY = 0;
 const uint8_t SPIOutput::SPI_BITS_PER_WORD = 8;
 const uint8_t SPIOutput::SPI_MODE = 0;
+
+/**
+ * These constants are used to determine the number of DMX Slots per pixel
+ * The p9813 uses another byte preceding each of the three bytes as a kind
+ * of header.
+ */
 const uint16_t SPIOutput::WS2801_SLOTS_PER_PIXEL = 3;
 const uint16_t SPIOutput::LPD8806_SLOTS_PER_PIXEL = 3;
+const uint16_t SPIOutput::P9813_SLOTS_PER_PIXEL = 3;
+
+// Number of bytes that each P9813 pixel uses on the spi wires
+const uint16_t SPIOutput::P9813_SPI_BYTES_PER_PIXEL = 4;
 
 SPIOutput::RDMOps *SPIOutput::RDMOps::instance = NULL;
 
@@ -104,6 +121,17 @@ const ola::rdm::ResponderOps<SPIOutput>::ParamHandler
   { ola::rdm::PID_IDENTIFY_DEVICE,
     &SPIOutput::GetIdentify,
     &SPIOutput::SetIdentify},
+#ifdef HAVE_GETLOADAVG
+  { ola::rdm::PID_SENSOR_DEFINITION,
+    &SPIOutput::GetSensorDefinition,
+    NULL},
+  { ola::rdm::PID_SENSOR_VALUE,
+    &SPIOutput::GetSensorValue,
+    &SPIOutput::SetSensorValue},
+  { ola::rdm::PID_RECORD_SENSORS,
+    NULL,
+    &SPIOutput::RecordSensor},
+#endif
   { 0, NULL, NULL},
 };
 
@@ -121,24 +149,45 @@ SPIOutput::SPIOutput(const UID &uid, SPIBackendInterface *backend,
   if (pos != string::npos)
     m_spi_device_name = device_path.substr(pos + 1);
 
-  m_personality_manager.AddPersonality(m_pixel_count * WS2801_SLOTS_PER_PIXEL,
-                                       "WS2801 Individual Control");
-  m_personality_manager.AddPersonality(WS2801_SLOTS_PER_PIXEL,
-                                       "WS2801 Combined Control");
-  m_personality_manager.AddPersonality(m_pixel_count * LPD8806_SLOTS_PER_PIXEL,
-                                       "LPD8806 Individual Control");
-  m_personality_manager.AddPersonality(LPD8806_SLOTS_PER_PIXEL,
-                                       "LPD8806 Combined Control");
-  m_personality_manager.SetActivePersonality(1);
+  PersonalityCollection::PersonalityList personalities;
+  personalities.push_back(Personality(m_pixel_count * WS2801_SLOTS_PER_PIXEL,
+                                      "WS2801 Individual Control"));
+  personalities.push_back(Personality(WS2801_SLOTS_PER_PIXEL,
+                                      "WS2801 Combined Control"));
+  personalities.push_back(Personality(m_pixel_count * LPD8806_SLOTS_PER_PIXEL,
+                                      "LPD8806 Individual Control"));
+  personalities.push_back(Personality(LPD8806_SLOTS_PER_PIXEL,
+                                      "LPD8806 Combined Control"));
+  personalities.push_back(Personality(m_pixel_count * P9813_SLOTS_PER_PIXEL,
+                                      "P9813 Individual Control"));
+  personalities.push_back(Personality(P9813_SLOTS_PER_PIXEL,
+                                      "P9813 Combined Control"));
+  m_personality_collection.reset(new PersonalityCollection(personalities));
+  m_personality_manager.reset(new PersonalityManager(
+      m_personality_collection.get()));
+  m_personality_manager->SetActivePersonality(1);
+
+#ifdef HAVE_GETLOADAVG
+  m_sensors.push_back(new LoadSensor(ola::system::LOAD_AVERAGE_1_MIN,
+                                     "Load Average 1 minute"));
+  m_sensors.push_back(new LoadSensor(ola::system::LOAD_AVERAGE_5_MINS,
+                                     "Load Average 5 minutes"));
+  m_sensors.push_back(new LoadSensor(ola::system::LOAD_AVERAGE_15_MINS,
+                                     "Load Average 15 minutes"));
+#endif
+}
+
+SPIOutput::~SPIOutput() {
+  STLDeleteElements(&m_sensors);
 }
 
 
 uint8_t SPIOutput::GetPersonality() const {
-  return m_personality_manager.ActivePersonalityNumber();
+  return m_personality_manager->ActivePersonalityNumber();
 }
 
 bool SPIOutput::SetPersonality(uint16_t personality) {
-  return m_personality_manager.SetActivePersonality(personality);
+  return m_personality_manager->SetActivePersonality(personality);
 }
 
 uint16_t SPIOutput::GetStartAddress() const {
@@ -146,7 +195,7 @@ uint16_t SPIOutput::GetStartAddress() const {
 }
 
 bool SPIOutput::SetStartAddress(uint16_t address) {
-  uint16_t footprint = m_personality_manager.ActivePersonalityFootprint();
+  uint16_t footprint = m_personality_manager->ActivePersonalityFootprint();
   uint16_t end_address = DMX_UNIVERSE_SIZE - footprint + 1;
   if (address == 0 || address > end_address || footprint == 0) {
     return false;
@@ -159,8 +208,8 @@ string SPIOutput::Description() const {
   std::ostringstream str;
   str << m_spi_device_name << ", output "
       << static_cast<int>(m_output_number) << ", "
-      << m_personality_manager.ActivePersonalityDescription() << ", "
-      << m_personality_manager.ActivePersonalityFootprint()
+      << m_personality_manager->ActivePersonalityDescription() << ", "
+      << m_personality_manager->ActivePersonalityFootprint()
       << " slots @ " << m_start_address << ". (" << m_uid << ")";
   return str.str();
 }
@@ -171,24 +220,7 @@ string SPIOutput::Description() const {
 bool SPIOutput::WriteDMX(const DmxBuffer &buffer) {
   if (m_identify_mode)
     return true;
-
-  switch (m_personality_manager.ActivePersonalityNumber()) {
-    case 1:
-      IndividualWS2801Control(buffer);
-      break;
-    case 2:
-      CombinedWS2801Control(buffer);
-      break;
-    case 3:
-      IndividualLPD8806Control(buffer);
-      break;
-    case 4:
-      CombinedLPD8806Control(buffer);
-      break;
-    default:
-      break;
-  }
-  return true;
+  return InternalWriteDMX(buffer);
 }
 
 
@@ -213,6 +245,32 @@ void SPIOutput::SendRDMRequest(const RDMRequest *request,
                                        request, callback);
 }
 
+bool SPIOutput::InternalWriteDMX(const DmxBuffer &buffer) {
+  switch (m_personality_manager->ActivePersonalityNumber()) {
+    case 1:
+      IndividualWS2801Control(buffer);
+      break;
+    case 2:
+      CombinedWS2801Control(buffer);
+      break;
+    case 3:
+      IndividualLPD8806Control(buffer);
+      break;
+    case 4:
+      CombinedLPD8806Control(buffer);
+      break;
+    case 5:
+      IndividualP9813Control(buffer);
+      break;
+    case 6:
+      CombinedP9813Control(buffer);
+      break;
+    default:
+      break;
+  }
+  return true;
+}
+
 void SPIOutput::IndividualWS2801Control(const DmxBuffer &buffer) {
   // We always check out the entire string length, even if we only have data
   // for part of it
@@ -310,19 +368,95 @@ void SPIOutput::CombinedLPD8806Control(const DmxBuffer &buffer) {
   m_backend->Commit(m_output_number);
 }
 
-const RDMResponse *SPIOutput::GetDeviceInfo(const RDMRequest *request) {
-  uint16_t footprint = m_personality_manager.ActivePersonalityFootprint();
-  if (request->ParamDataSize()) {
-    return NackWithReason(request, NR_FORMAT_ERROR);
+void SPIOutput::IndividualP9813Control(const DmxBuffer &buffer) {
+  // We need 4 bytes of zeros in the beginning and 8 bytes at
+  // the end
+  const uint8_t latch_bytes = 3 * P9813_SPI_BYTES_PER_PIXEL;
+  const unsigned int first_slot = m_start_address - 1;  // 0 offset
+  if (buffer.Size() - first_slot < P9813_SLOTS_PER_PIXEL) {
+    // not even 3 bytes of data, don't bother updating
+    return;
   }
+
+  // We always check out the entire string length, even if we only have data
+  // for part of it
+  const unsigned int output_length = m_pixel_count * P9813_SPI_BYTES_PER_PIXEL;
+  uint8_t *output = m_backend->Checkout(m_output_number, output_length,
+                                        latch_bytes);
+
+  if (!output)
+    return;
+
+  for (unsigned int i = 0; i < m_pixel_count; i++) {
+    // Convert RGB to P9813 Pixel
+    unsigned int offset = first_slot + i * P9813_SLOTS_PER_PIXEL;
+    // We need to avoid the first 4 bytes of the buffer since that acts as a
+    // start of frame delimiter
+    unsigned int spi_offset = (i + 1) * P9813_SPI_BYTES_PER_PIXEL;
+    uint8_t r = 0;
+    uint8_t b = 0;
+    uint8_t g = 0;
+    if (buffer.Size() - offset >= P9813_SLOTS_PER_PIXEL) {
+      r = buffer.Get(offset);
+      g = buffer.Get(offset + 1);
+      b = buffer.Get(offset + 2);
+    }
+    output[spi_offset] = P9813CreateFlag(r, g, b);
+    output[spi_offset + 1] = b;
+    output[spi_offset + 2] = g;
+    output[spi_offset + 3] = r;
+  }
+  m_backend->Commit(m_output_number);
+}
+
+void SPIOutput::CombinedP9813Control(const DmxBuffer &buffer) {
+  const uint8_t latch_bytes = 3 * P9813_SPI_BYTES_PER_PIXEL;
+  const unsigned int first_slot = m_start_address - 1;  // 0 offset
+
+  if (buffer.Size() - first_slot < P9813_SLOTS_PER_PIXEL) {
+    OLA_INFO << "Insufficient DMX data, required " << P9813_SLOTS_PER_PIXEL
+             << ", got " << buffer.Size() - first_slot;
+    return;
+  }
+
+  uint8_t pixel_data[P9813_SPI_BYTES_PER_PIXEL];
+  pixel_data[3] = buffer.Get(first_slot);  // Get Red
+  pixel_data[2] = buffer.Get(first_slot + 1);  // Get Green
+  pixel_data[1] = buffer.Get(first_slot + 2);  // Get Blue
+  pixel_data[0] = P9813CreateFlag(pixel_data[3], pixel_data[2],
+                                  pixel_data[1]);
+
+  const unsigned int length = m_pixel_count * P9813_SPI_BYTES_PER_PIXEL;
+  uint8_t *output = m_backend->Checkout(m_output_number, length, latch_bytes);
+  if (!output)
+    return;
+
+  for (unsigned int i = 0; i < m_pixel_count; i++) {
+    memcpy(&output[(i + 1) * P9813_SPI_BYTES_PER_PIXEL], pixel_data,
+           P9813_SPI_BYTES_PER_PIXEL);
+  }
+  m_backend->Commit(m_output_number);
+}
+
+/**
+ * For more information please visit:
+ * https://github.com/CoolNeon/elinux-tcl/blob/master/README.txt
+ */
+uint8_t SPIOutput::P9813CreateFlag(uint8_t red, uint8_t green, uint8_t blue) {
+  uint8_t flag = 0;
+  flag =  (red & 0xc0) >> 6;
+  flag |= (green & 0xc0) >> 4;
+  flag |= (blue & 0xc0) >> 2;
+  return ~flag;
+}
+
+const RDMResponse *SPIOutput::GetDeviceInfo(const RDMRequest *request) {
   return ResponderHelper::GetDeviceInfo(
       request, ola::rdm::OLA_SPI_DEVICE_MODEL,
-      ola::rdm::PRODUCT_CATEGORY_FIXTURE, 1,
-      footprint,
-      m_personality_manager.ActivePersonalityNumber(),
-      m_personality_manager.PersonalityCount(),
-      footprint ? m_start_address : ola::rdm::ZERO_FOOTPRINT_DMX_ADDRESS,
-      0, 0);
+      ola::rdm::PRODUCT_CATEGORY_FIXTURE, 2,
+      m_personality_manager.get(),
+      m_start_address,
+      0, m_sensors.size());
 }
 
 const RDMResponse *SPIOutput::GetProductDetailList(
@@ -355,95 +489,28 @@ const RDMResponse *SPIOutput::GetSoftwareVersionLabel(
 }
 
 const RDMResponse *SPIOutput::GetDmxPersonality(const RDMRequest *request) {
-  if (request->ParamDataSize()) {
-    return NackWithReason(request, NR_FORMAT_ERROR);
-  }
-
-  struct personality_info_s {
-    uint8_t personality;
-    uint8_t total;
-  } __attribute__((packed));
-
-  struct personality_info_s personality_info = {
-    m_personality_manager.ActivePersonalityNumber(),
-    m_personality_manager.PersonalityCount()
-  };
-  return GetResponseFromData(
-    request,
-    reinterpret_cast<const uint8_t*>(&personality_info),
-    sizeof(personality_info));
+  return ResponderHelper::GetPersonality(request, m_personality_manager.get());
 }
 
 const RDMResponse *SPIOutput::SetDmxPersonality(const RDMRequest *request) {
-  uint8_t personality_number;
-  if (!ResponderHelper::ExtractUInt8(request, &personality_number)) {
-    return NackWithReason(request, NR_FORMAT_ERROR);
-  }
-
-  const Personality *personality = m_personality_manager.Lookup(
-      personality_number);
-
-  if (!personality) {
-    return NackWithReason(request, NR_DATA_OUT_OF_RANGE);
-  }
-  if (m_start_address + personality->footprint() - 1 > DMX_UNIVERSE_SIZE) {
-    return NackWithReason(request, NR_DATA_OUT_OF_RANGE);
-  }
-
-  m_personality_manager.SetActivePersonality(personality_number);
-  return ResponderHelper::EmptySetResponse(request);
+  return ResponderHelper::SetPersonality(request, m_personality_manager.get(),
+                                         m_start_address);
 }
 
 const RDMResponse *SPIOutput::GetPersonalityDescription(
     const RDMRequest *request) {
-  uint8_t personality_number;
-  if (!ResponderHelper::ExtractUInt8(request, &personality_number)) {
-    return NackWithReason(request, NR_FORMAT_ERROR);
-  }
-
-  const Personality *personality = m_personality_manager.Lookup(
-      personality_number);
-  if (!personality) {
-    return NackWithReason(request, NR_DATA_OUT_OF_RANGE);
-  }
-
-  struct personality_description_s {
-    uint8_t personality;
-    uint16_t slots_required;
-    char description[32];
-  } __attribute__((packed));
-
-  struct personality_description_s personality_description = {
-    personality_number, HostToNetwork(personality->footprint()), ""
-  };
-  strncpy(personality_description.description,
-          personality->description().c_str(),
-          sizeof(personality_description.description));
-
-  return GetResponseFromData(
-      request,
-      reinterpret_cast<uint8_t*>(&personality_description),
-      sizeof(personality_description));
+  return ResponderHelper::GetPersonalityDescription(
+      request, m_personality_manager.get());
 }
 
 const RDMResponse *SPIOutput::GetDmxStartAddress(const RDMRequest *request) {
-  return ResponderHelper::GetUInt16Value(
-    request,
-    ((m_personality_manager.ActivePersonalityFootprint() == 0) ?
-     ola::rdm::ZERO_FOOTPRINT_DMX_ADDRESS : m_start_address));
+  return ResponderHelper::GetDmxAddress(request, m_personality_manager.get(),
+                                        m_start_address);
 }
 
 const RDMResponse *SPIOutput::SetDmxStartAddress(const RDMRequest *request) {
-  uint16_t address;
-  if (!ResponderHelper::ExtractUInt16(request, &address)) {
-    return NackWithReason(request, NR_FORMAT_ERROR);
-  }
-  if (!SetStartAddress(address)) {
-    return NackWithReason(request, NR_DATA_OUT_OF_RANGE);
-  }
-
-  m_start_address = address;
-  return ResponderHelper::EmptySetResponse(request);
+  return ResponderHelper::SetDmxAddress(request, m_personality_manager.get(),
+                                        &m_start_address);
 }
 
 const RDMResponse *SPIOutput::GetIdentify(const RDMRequest *request) {
@@ -458,14 +525,42 @@ const RDMResponse *SPIOutput::SetIdentify(const RDMRequest *request) {
     OLA_INFO << "SPI " << m_spi_device_name << " identify mode " << (
         m_identify_mode ? "on" : "off");
     DmxBuffer identify_buffer;
-    if (m_identify_mode)
+    if (m_identify_mode) {
       identify_buffer.SetRangeToValue(0, DMX_MAX_CHANNEL_VALUE,
                                       DMX_UNIVERSE_SIZE);
-    else
+    } else {
       identify_buffer.Blackout();
+    }
+    InternalWriteDMX(identify_buffer);
   }
   return response;
 }
+
+/**
+ * PID_SENSOR_DEFINITION
+ */
+const RDMResponse *SPIOutput::GetSensorDefinition(
+    const RDMRequest *request) {
+  return ResponderHelper::GetSensorDefinition(request, m_sensors);
+}
+
+/**
+ * PID_SENSOR_VALUE
+ */
+const RDMResponse *SPIOutput::GetSensorValue(const RDMRequest *request) {
+  return ResponderHelper::GetSensorValue(request, m_sensors);
+}
+
+const RDMResponse *SPIOutput::SetSensorValue(const RDMRequest *request) {
+  return ResponderHelper::SetSensorValue(request, m_sensors);
+}
+
+/**
+ * PID_RECORD_SENSORS
+ */
+const RDMResponse *SPIOutput::RecordSensor(const RDMRequest *request) {
+  return ResponderHelper::RecordSensor(request, m_sensors);
+}
 }  // namespace spi
 }  // namespace plugin
 }  // namespace ola
