@@ -22,7 +22,6 @@
 #define PLUGINS_SPI_SPIPORT_H_
 
 #include <string>
-#include <vector>
 #include "ola/DmxBuffer.h"
 #include "olad/Port.h"
 #include "plugins/spi/SPIDevice.h"
@@ -33,9 +32,9 @@ namespace plugin {
 namespace spi {
 
 class SPIOutputPort: public BasicOutputPort {
-  public:
+ public:
     SPIOutputPort(SPIDevice *parent, class SPIBackendInterface *backend,
-                  const UID &uid, const SPIOutput::Options &options);
+                  const ola::rdm::UID &uid, const SPIOutput::Options &options);
     ~SPIOutputPort() {}
 
     uint8_t GetPersonality() const;
@@ -44,15 +43,15 @@ class SPIOutputPort: public BasicOutputPort {
     bool SetStartAddress(uint16_t start_address);
     unsigned int PixelCount() const;
 
-    string Description() const;
+    std::string Description() const;
     bool WriteDMX(const DmxBuffer &buffer, uint8_t priority);
 
-    void RunFullDiscovery(RDMDiscoveryCallback *callback);
-    void RunIncrementalDiscovery(RDMDiscoveryCallback *callback);
+    void RunFullDiscovery(ola::rdm::RDMDiscoveryCallback *callback);
+    void RunIncrementalDiscovery(ola::rdm::RDMDiscoveryCallback *callback);
     void SendRDMRequest(const ola::rdm::RDMRequest *request,
                         ola::rdm::RDMCallback *callback);
 
-  private:
+ private:
     SPIOutput m_spi_output;
 };
 }  // namespace spi
