@@ -33,15 +33,15 @@ namespace usbdmx {
  * A Velleman device
  */
 class VellemanDevice: public UsbDevice {
-  public:
+ public:
     VellemanDevice(ola::AbstractPlugin *owner,
                    libusb_device *usb_device):
         UsbDevice(owner, "Velleman USB Device", usb_device) {
     }
 
-    string DeviceId() const { return "velleman"; }
+    std::string DeviceId() const { return "velleman"; }
 
-  protected:
+ protected:
     bool StartHook();
 };
 }  // namespace usbdmx
