@@ -31,12 +31,16 @@
 #include <string>
 #include "ola/BaseTypes.h"
 #include "ola/Logging.h"
+#include "ola/io/IOUtils.h"
 #include "plugins/usbpro/BaseUsbProWidget.h"
 
 namespace ola {
 namespace plugin {
 namespace usbpro {
 
+using std::string;
+
+
 const unsigned int BaseUsbProWidget::HEADER_SIZE =
   sizeof(BaseUsbProWidget::message_header);
 
@@ -121,10 +125,8 @@ bool BaseUsbProWidget::SendMessage(uint8_t label,
 ola::io::ConnectedDescriptor *BaseUsbProWidget::OpenDevice(
     const string &path) {
   struct termios newtio;
-  int fd = open(path.data(), O_RDWR | O_NONBLOCK | O_NOCTTY);
-
-  if (fd == -1) {
-    OLA_WARN << "Failed to open " << path << " " << strerror(errno);
+  int fd;
+  if (!ola::io::Open(path, O_RDWR | O_NONBLOCK | O_NOCTTY, &fd)) {
     return NULL;
   }
 
