@@ -84,11 +84,14 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "config.ypp"
+#line 1 "./config.ypp"
 
+#include <string>
+#include <utility>
+#include <vector>
 #include <ola/Logging.h>
-#include "ConfigCommon.h"
-#include "ParserActions.h"
+#include "tools/ola_trigger/ConfigCommon.h"
+#include "tools/ola_trigger/ParserActions.h"
 int yyerror(const char *s);
 int yylex(void);
 
@@ -114,18 +117,18 @@ int yylex(void);
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 10 "config.ypp"
+#line 13 "./config.ypp"
 {
   unsigned int int_val;
-  string *str_val;
-  vector<string> *str_list;
+  std::string *str_val;
+  std::vector<std::string> *str_list;
   class Action *action;
   IntervalList *interval_list;
   ValueInterval *interval;
-  pair<Action*, Action*> *action_pair;
+  std::pair<Action*, Action*> *action_pair;
 }
 /* Line 193 of yacc.c.  */
-#line 129 "config.tab.cpp"
+#line 132 "config.tab.cpp"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -138,7 +141,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 142 "config.tab.cpp"
+#line 145 "config.tab.cpp"
 
 #ifdef short
 # undef short
@@ -432,10 +435,10 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    42,    42,    44,    48,    49,    53,    54,    58,    68,
-      69,    72,    74,    78,    89,    90,    94,    95,    99,   100,
-     104,   105,   106,   112,   116,   117,   121,   122,   129,   130,
-     137,   138,   142,   143,   147,   148
+       0,    45,    45,    47,    51,    52,    56,    57,    61,    71,
+      72,    75,    77,    81,    92,    93,    97,    98,   102,   103,
+     107,   108,   109,   115,   119,   120,   124,   125,   132,   133,
+     140,   141,   145,   146,   150,   151
 };
 #endif
 
@@ -1369,14 +1372,14 @@ yyreduce:
   switch (yyn)
     {
         case 6:
-#line 53 "config.ypp"
+#line 56 "./config.ypp"
     { SetDefaultValue((yyvsp[(1) - (1)].str_list)); ;}
     break;
 
   case 8:
-#line 58 "config.ypp"
+#line 61 "./config.ypp"
     {
-        (yyval.str_list) = new vector<string>;
+        (yyval.str_list) = new std::vector<std::string>;
         (yyval.str_list)->push_back(*(yyvsp[(1) - (5)].str_val));
         (yyval.str_list)->push_back(*(yyvsp[(5) - (5)].str_val));
         delete (yyvsp[(1) - (5)].str_val);
@@ -1385,7 +1388,7 @@ yyreduce:
     break;
 
   case 13:
-#line 78 "config.ypp"
+#line 81 "./config.ypp"
     {
         if ((yyvsp[(3) - (5)].interval_list) == NULL) {
           SetDefaultAction((yyvsp[(1) - (5)].int_val), (yyvsp[(5) - (5)].action_pair)->first, (yyvsp[(5) - (5)].action_pair)->second);
@@ -1397,74 +1400,74 @@ yyreduce:
     break;
 
   case 14:
-#line 89 "config.ypp"
+#line 92 "./config.ypp"
     { (yyval.interval_list) = NULL; ;}
     break;
 
   case 15:
-#line 90 "config.ypp"
+#line 93 "./config.ypp"
     { (yyval.interval_list) = (yyvsp[(1) - (1)].interval_list); ;}
     break;
 
   case 16:
-#line 94 "config.ypp"
+#line 97 "./config.ypp"
     { (yyval.interval_list) = new IntervalList(); (yyval.interval_list)->push_back((yyvsp[(1) - (1)].interval)); ;}
     break;
 
   case 17:
-#line 95 "config.ypp"
+#line 98 "./config.ypp"
     { (yyval.interval_list) = (yyvsp[(1) - (3)].interval_list); (yyval.interval_list)->push_back((yyvsp[(3) - (3)].interval)); ;}
     break;
 
   case 18:
-#line 99 "config.ypp"
+#line 102 "./config.ypp"
     { (yyval.interval) = CreateInterval((yyvsp[(1) - (1)].int_val), (yyvsp[(1) - (1)].int_val)); ;}
     break;
 
   case 19:
-#line 100 "config.ypp"
+#line 103 "./config.ypp"
     { (yyval.interval) = CreateInterval((yyvsp[(1) - (3)].int_val), (yyvsp[(3) - (3)].int_val)); ;}
     break;
 
   case 20:
-#line 104 "config.ypp"
+#line 107 "./config.ypp"
     { (yyval.action_pair) = new ActionPair((yyvsp[(1) - (1)].action), (yyvsp[(1) - (1)].action)); ;}
     break;
 
   case 21:
-#line 105 "config.ypp"
+#line 108 "./config.ypp"
     { (yyval.action_pair) = new ActionPair(NULL, (yyvsp[(1) - (1)].action)); ;}
     break;
 
   case 22:
-#line 106 "config.ypp"
+#line 109 "./config.ypp"
     {
-        (yyval.action_pair) = new pair<Action*, Action*>((yyvsp[(2) - (3)].action), (yyvsp[(3) - (3)].action));
+        (yyval.action_pair) = new std::pair<Action*, Action*>((yyvsp[(2) - (3)].action), (yyvsp[(3) - (3)].action));
       ;}
     break;
 
   case 23:
-#line 112 "config.ypp"
+#line 115 "./config.ypp"
     { (yyval.action) = (yyvsp[(2) - (2)].action); ;}
     break;
 
   case 24:
-#line 116 "config.ypp"
+#line 119 "./config.ypp"
     { (yyval.action) = NULL; ;}
     break;
 
   case 25:
-#line 117 "config.ypp"
+#line 120 "./config.ypp"
     { (yyval.action) = (yyvsp[(2) - (2)].action); ;}
     break;
 
   case 26:
-#line 121 "config.ypp"
+#line 124 "./config.ypp"
     { (yyval.action) = CreateAssignmentAction((yyvsp[(1) - (1)].str_list)); ;}
     break;
 
   case 27:
-#line 122 "config.ypp"
+#line 125 "./config.ypp"
     {
         (yyval.action) = CreateCommandAction(*(yyvsp[(2) - (4)].str_val), (yyvsp[(3) - (4)].str_list));
         delete (yyvsp[(2) - (4)].str_val);
@@ -1472,27 +1475,27 @@ yyreduce:
     break;
 
   case 28:
-#line 129 "config.ypp"
-    { (yyval.str_list) = new vector<string>(); ;}
+#line 132 "./config.ypp"
+    { (yyval.str_list) = new std::vector<std::string>(); ;}
     break;
 
   case 29:
-#line 130 "config.ypp"
+#line 133 "./config.ypp"
     {
-        (yyval.str_list) = (yyvsp[(1) - (3)].str_list); (yyval.str_list)->push_back(string(*(yyvsp[(3) - (3)].str_val)));
+        (yyval.str_list) = (yyvsp[(1) - (3)].str_list); (yyval.str_list)->push_back(std::string(*(yyvsp[(3) - (3)].str_val)));
         delete (yyvsp[(3) - (3)].str_val);
     ;}
     break;
 
   case 34:
-#line 147 "config.ypp"
-    { (yyval.str_val) = new string("/"); (yyval.str_val)->append(*(yyvsp[(2) - (2)].str_val)); ;}
+#line 150 "./config.ypp"
+    { (yyval.str_val) = new std::string("/"); (yyval.str_val)->append(*(yyvsp[(2) - (2)].str_val)); ;}
     break;
 
   case 35:
-#line 148 "config.ypp"
+#line 151 "./config.ypp"
     {
-        (yyval.str_val) = new string(*(yyvsp[(1) - (3)].str_val));
+        (yyval.str_val) = new std::string(*(yyvsp[(1) - (3)].str_val));
         (yyval.str_val)->append("/");
         (yyval.str_val)->append(*(yyvsp[(3) - (3)].str_val));
         delete (yyvsp[(1) - (3)].str_val);
@@ -1502,7 +1505,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1506 "config.tab.cpp"
+#line 1509 "config.tab.cpp"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1716,11 +1719,11 @@ yyreturn:
 }
 
 
-#line 157 "config.ypp"
+#line 160 "./config.ypp"
 
 extern int column;
 
-int yyerror(string s) {
+int yyerror(std::string s) {
   extern int yylineno;  // defined and maintained in lex.yy.cpp
   extern char *yytext;  // defined and maintained in lex.yy.cpp
 
@@ -1730,6 +1733,6 @@ int yyerror(string s) {
 }
 
 int yyerror(const char *s) {
-  return yyerror(string(s));
+  return yyerror(std::string(s));
 }
 
